@@ -34,102 +34,93 @@
 #include "base.h"
 
 //============ Modul info! =====================================================
-#define NAME_MODUL  "base_arh"
-#define NAME_TYPE   "Arhiv"
+#define MOD_ID      "base_arh"
+#define MOD_NAME    "Base archivator"
+#define MOD_TYPE    "Archive"
 #define VER_TYPE    VER_ARH
-#define VERSION     "0.1.0"
+#define VERSION     "0.3.0"
 #define AUTORS      "Roman Savochenko"
-#define DESCRIPTION "The Arhive module support base function of message arhiving."
+#define DESCRIPTION "The Archive module. Allow base functions of message and value arhiving."
 #define LICENSE     "GPL"
 //==============================================================================
 
 extern "C"
 { 
-    SAtMod module( int n_mod )
+    TModule::SAt module( int n_mod )
     {
-	SAtMod AtMod;
+	TModule::SAt AtMod;
 	
 	if(n_mod==0) 
 	{
-	    AtMod.name  = NAME_MODUL;
-	    AtMod.type  = NAME_TYPE;
+	    AtMod.id	= MOD_ID;
+	    AtMod.type  = MOD_TYPE;
 	    AtMod.t_ver = VER_TYPE;
 	}
 	else
-	    AtMod.name  = "";
+	    AtMod.id	= "";
 	return( AtMod );    
     }
     
-    TModule *attach( const SAtMod &AtMod, const string &source )
+    TModule *attach( const TModule::SAt &AtMod, const string &source )
     {
-	BaseArh::TMArhive *self_addr = NULL;
+	BaseArch::TMArchive *self_addr = NULL;
 	
-	if( AtMod.name == NAME_MODUL && AtMod.type == NAME_TYPE && AtMod.t_ver == VER_TYPE ) 
-	    self_addr = new BaseArh::TMArhive( source );
+	if( AtMod.id == MOD_ID && AtMod.type == MOD_TYPE && AtMod.t_ver == VER_TYPE ) 
+	    self_addr = new BaseArch::TMArchive( source );
 	    
 	return ( self_addr );
     }    
 }
 
-using namespace BaseArh;
+using namespace BaseArch;
 
 //==============================================================================
-//================= BaseArh::TMArhive ==========================================
+//================= BaseArch::TMArchive ========================================
 //==============================================================================
-const char *TMArhive::i_cntr = 
-    "<area id='bs'>"
-    " <area id='opt' acs='0440'>"
-    "  <fld id='a_ch' acs='0660' tp='str'/>"
-    "  <fld id='a_sz' acs='0660' tp='dec'/>"
-    "  <fld id='a_fl' acs='0660' tp='dec'/>"
-    "  <fld id='a_len' acs='0660' tp='dec'/>"
-    "  <fld id='a_tm' acs='0660' tp='dec'/>"
-    "  <fld id='o_help' acs='0440' tp='str' cols='90' rows='5'/>"
-    " </area>"
-    "</area>";
-
-TMArhive::TMArhive( const string &name) : m_mess_max_size(0), m_mess_numb_file(5), m_mess_time_size(7), m_mess_charset("UTF8")
+TMArchive::TMArchive( const string &name) : m_mess_max_size(0), m_mess_numb_file(5), m_mess_time_size(7), m_mess_charset("UTF8")
 {
-    NameModul = NAME_MODUL;
-    NameType  = NAME_TYPE;
-    Vers      = VERSION;
-    Autors    = AUTORS;
-    DescrMod  = DESCRIPTION;
-    License   = LICENSE;
-    Source    = name;
+    mId 	= MOD_ID;
+    mName	= MOD_NAME;
+    mType  	= MOD_TYPE;
+    Vers      	= VERSION;
+    Autors    	= AUTORS;
+    DescrMod  	= DESCRIPTION;
+    License   	= LICENSE;
+    Source    	= name;
 }
 
-TMArhive::~TMArhive()
+TMArchive::~TMArchive()
 {
 
 }
 
-string TMArhive::opt_descr( )
+string TMArchive::optDescr( )
 {
     char buf[STR_BUF_LEN];
 
     snprintf(buf,sizeof(buf),I18N(
-	"=========================== The module options ===========================\n"
-	"------------ Parameters of module <%s> in config file ------------\n"
-    	"mess_charset      <name>    set charset <name> of arhive (default UTF8);\n"
-    	"mess_max_size     <size>    maximum <size> kb of message arhive file (0 - unlimited default);\n"
-    	"mess_numb_file    <number>  number of message arhive files (5 - default);\n"
+	"======================= The module <%s:%s> options =======================\n"
+	"---------- Parameters of the module section <%s> in config file ----------\n"
+    	"mess_charset      <name>    charset <name> of the Archive (default UTF8);\n"
+    	"mess_max_size     <size>    maximum <size> kb of message Archive file (0 - unlimited default);\n"
+    	"mess_numb_file    <number>  number of message Archive files (5 - default);\n"
     	"mess_time_size    <days>    number days to one message file (7 days - default);\n"
-    	"mess_timeout_free <min>     timeout of free message file buffer. Timeout no access (10 min default);\n"),
-	NAME_MODUL);
+    	"mess_timeout_free <min>     timeout of free message file buffer. Timeout no access (10 min default);\n\n"),
+	MOD_TYPE,MOD_ID,MOD_ID);
 
     return(buf);
 }
 
-void TMArhive::mod_CheckCommandLine( ) 
+void TMArchive::modCheckCommandLine( ) 
 {
-    TModule::mod_CheckCommandLine();
+    TModule::modCheckCommandLine();
     
     int next_opt;
     char *short_opt="h";
     struct option long_opt[] =
     {
-	{NULL        ,0,NULL,0  }
+	{"help"    ,0,NULL,'h'},
+	{NULL      ,0,NULL,0  }
     };
 
     optind=opterr=0;
@@ -138,161 +129,158 @@ void TMArhive::mod_CheckCommandLine( )
 	next_opt=getopt_long(SYS->argc,(char * const *)SYS->argv,short_opt,long_opt,NULL);
 	switch(next_opt)
 	{
-	    case 'h': fprintf(stdout,opt_descr().c_str()); break;
+	    case 'h': fprintf(stdout,optDescr().c_str()); break;
 	    case -1 : break;
 	}
     } while(next_opt != -1);
 }
 
-void TMArhive::mod_UpdateOpt()
+void TMArchive::modUpdateOpt()
 {
-    TModule::mod_UpdateOpt();
+    TModule::modUpdateOpt();
     
     int val;
     try
     { 
-	val = atoi( mod_XMLCfgNode()->get_child("id","mess_max_size")->get_text().c_str() ); 
+	val = atoi( modCfgNode()->childGet("id","mess_max_size")->text().c_str() ); 
     	if(val >= 0) m_mess_max_size = val;
     }
     catch(...){ }
     try
     { 
-	val = atoi( mod_XMLCfgNode()->get_child("id","mess_numb_file")->get_text().c_str() ); 
+	val = atoi( modCfgNode()->childGet("id","mess_numb_file")->text().c_str() ); 
     	if(val > 0) m_mess_numb_file = val;
     }
     catch(...){ }
     try
     {
-	val = atoi( mod_XMLCfgNode()->get_child("id","mess_time_size")->get_text().c_str() ); 
+	val = atoi( modCfgNode()->childGet("id","mess_time_size")->text().c_str() ); 
     	if(val > 0) m_mess_time_size = val;
     }
     catch(...){ }
-    try{ m_mess_charset = mod_XMLCfgNode()->get_child("id","mess_charset")->get_text(); }
+    try{ m_mess_charset = modCfgNode()->childGet("id","mess_charset")->text(); }
     catch(...){ }
     try
     {
-	val = atoi( mod_XMLCfgNode()->get_child("id","mess_timeout_free")->get_text().c_str() ); 
+	val = atoi( modCfgNode()->childGet("id","mess_timeout_free")->text().c_str() ); 
     	if(val > 0) m_mess_timeout_free = val;
     }
     catch(...){ }
 }
 
-void TMArhive::mod_connect(  )
+void TMArchive::modConnect(  )
 {
-    TModule::mod_connect(  );
+    TModule::modConnect(  );
 }
 
-TArhiveMess *TMArhive::AMess(const string &name)
+TArchiveMess *TMArchive::AMess(const string &name)
 {
-    return( new	TMessArh(name,this) );
+    return( new	TMessArch(name,this) );
 }
 
 //================== Controll functions ========================
-void TMArhive::ctr_fill_info( XMLNode *inf )
+void TMArchive::ctrStat_( XMLNode *inf )
 {
     char *dscr = "dscr";
-    TTipArhive::ctr_fill_info( inf );
+    TTipArchive::ctrStat_( inf );
     
-    XMLNode *n_add = inf->add_child();
-    n_add->load_xml(i_cntr);
-    n_add->set_attr(dscr,I18N("Self modul"));
-    n_add = n_add->get_child(0);
-    n_add->set_attr(dscr,I18N("The message arhive options"));
-    n_add->get_child(0)->set_attr(dscr,I18N("Internal arhive charset"));
-    n_add->get_child(1)->set_attr(dscr,I18N("Maximum arhive size(byte)"));
-    n_add->get_child(2)->set_attr(dscr,I18N("Maximum arhive files"));
-    n_add->get_child(3)->set_attr(dscr,I18N("Maximum arhive length time(days)"));
-    n_add->get_child(4)->set_attr(dscr,I18N("Timeout freeing buffer of no used arhives(min)"));
-    n_add->get_child(5)->set_attr(dscr,I18N("Options help"));
+    char *i_cntr = 
+    	"<area id='bs'>"
+       	" <area id='opt' acs='0440'>"
+	"  <fld id='a_ch' acs='0660' tp='str'/>"
+	"  <fld id='a_sz' acs='0660' tp='dec'/>"
+	"  <fld id='a_fl' acs='0660' tp='dec'/>"
+	"  <fld id='a_len' acs='0660' tp='dec'/>"
+	"  <fld id='a_tm' acs='0660' tp='dec'/>"
+	" </area>"
+	"</area>";
+    
+    XMLNode *n_add = inf->childIns(1);
+    n_add->load(i_cntr);
+    n_add->attr(dscr,I18N(MOD_NAME));
+    n_add = n_add->childGet(0);
+    n_add->attr(dscr,I18N("The message Archive options"));
+    n_add->childGet(0)->attr(dscr,I18N("Internal Archive charset"));
+    n_add->childGet(1)->attr(dscr,I18N("Maximum Archive size(byte)"));
+    n_add->childGet(2)->attr(dscr,I18N("Maximum Archive files"));
+    n_add->childGet(3)->attr(dscr,I18N("Maximum Archive length time(days)"));
+    n_add->childGet(4)->attr(dscr,I18N("Timeout freeing buffer of no used Archives(min)"));
+    
+    //Insert to Help
+    char *i_help = "<fld id='g_help' acs='0440' tp='str' cols='90' rows='5'/>";
+    
+    n_add = inf->childGet("id","help")->childAdd();    
+    n_add->load(i_help);     
+    n_add->attr(dscr,Mess->I18N("Options help"));
 }
 
-void TMArhive::ctr_din_get_( const string &a_path, XMLNode *opt )
+void TMArchive::ctrDinGet_( const string &a_path, XMLNode *opt )
 {
-    TTipArhive::ctr_din_get_( a_path, opt );
-
-    string t_id = ctr_path_l(a_path,0);
-    if( t_id == "bs" )
-    {
-	t_id = ctr_path_l(a_path,1);
-	if( t_id == "opt" )
-	{
-	    t_id = ctr_path_l(a_path,2);
-	    if( t_id == "a_ch" )        ctr_opt_setS( opt, m_mess_charset );
-	    else if( t_id == "a_sz" )   ctr_opt_setI( opt, m_mess_max_size );
-	    else if( t_id == "a_fl" )   ctr_opt_setI( opt, m_mess_numb_file );
-	    else if( t_id == "a_len" )  ctr_opt_setI( opt, m_mess_time_size );
-	    else if( t_id == "a_tm" )   ctr_opt_setI( opt, m_mess_timeout_free );
-	    else if( t_id == "o_help" ) ctr_opt_setS( opt, opt_descr() );       
-	}
-    }
+    if( a_path == "/bs/opt/a_ch" )	ctrSetS( opt, m_mess_charset );
+    else if( a_path == "/bs/opt/a_sz" ) ctrSetI( opt, m_mess_max_size );
+    else if( a_path == "/bs/opt/a_fl" ) ctrSetI( opt, m_mess_numb_file );
+    else if( a_path == "/bs/opt/a_len" )ctrSetI( opt, m_mess_time_size );
+    else if( a_path == "/bs/opt/a_tm" )	ctrSetI( opt, m_mess_timeout_free );
+    else if( a_path == "/help/g_help" )	ctrSetS( opt, optDescr() );       
+    else TTipArchive::ctrDinGet_( a_path, opt );
 }
 
-void TMArhive::ctr_din_set_( const string &a_path, XMLNode *opt )
+void TMArchive::ctrDinSet_( const string &a_path, XMLNode *opt )
 {
-    TTipArhive::ctr_din_set_( a_path, opt );
-    
-    string t_id = ctr_path_l(a_path,0);
-    if( t_id == "bs" )
-    {
-	t_id = ctr_path_l(a_path,1);
-	if( t_id == "opt" )
-	{
-	    t_id = ctr_path_l(a_path,2);
-	    if( t_id == "a_ch" )        m_mess_charset = ctr_opt_getS( opt );
-	    else if( t_id == "a_sz" )   m_mess_max_size = ctr_opt_getI( opt );
-	    else if( t_id == "a_fl" )   m_mess_numb_file = ctr_opt_getI( opt );
-	    else if( t_id == "a_len" )  m_mess_time_size = ctr_opt_getI( opt );
-	    else if( t_id == "a_tm" )   m_mess_timeout_free = ctr_opt_getI( opt );
-	}
-    }
+    if( a_path == "/bs/opt/a_ch" )	m_mess_charset = ctrGetS( opt );
+    else if( a_path == "/bs/opt/a_sz" ) m_mess_max_size = ctrGetI( opt );
+    else if( a_path == "/bs/opt/a_fl" ) m_mess_numb_file = ctrGetI( opt );
+    else if( a_path == "/bs/opt/a_len" )m_mess_time_size = ctrGetI( opt );
+    else if( a_path == "/bs/opt/a_tm" )	m_mess_timeout_free = ctrGetI( opt );
+    else TTipArchive::ctrDinSet_( a_path, opt );
 }
 
 //==============================================================================
-//================= BaseArh::TMessArh ==========================================
+//================= BaseArch::TMessArch ========================================
 //==============================================================================
-TMessArh::TMessArh( const string &name, TTipArhive *owner ) : 
-    TArhiveMess( name, owner ), m_endrun(false)
+TMessArch::TMessArch( const string &name, TTipArchive *owner ) : 
+    TArchiveMess( name, owner ), m_endrun(false)
 {
-    m_res = ResAlloc::ResCreate( );
+    m_res = ResAlloc::resCreate( );
 }
 
-TMessArh::~TMessArh( )
+TMessArch::~TMessArch( )
 {
     try{ stop(); }catch(...){}
     
-    ResAlloc::ResDelete( m_res );
+    ResAlloc::resDelete( m_res );
 }
 
-void TMessArh::start()
+void TMessArch::start()
 {
-    if(run_st) throw TError("(%s) Arhive %s already started!",NAME_MODUL,Name().c_str());
+    if(run_st) throw TError("(%s) Archive %s already started!",MOD_ID,name().c_str());
     //start thread
     pthread_attr_t pthr_attr;
     pthread_attr_init(&pthr_attr);
     pthread_attr_setschedpolicy(&pthr_attr,SCHED_OTHER);
-    pthread_create(&m_pthr,&pthr_attr,TMessArh::Task,this);
+    pthread_create(&m_pthr,&pthr_attr,TMessArch::Task,this);
     pthread_attr_destroy(&pthr_attr);
-    if( SYS->event_wait( run_st, true, string(NAME_MODUL)+": Task of message arhiv "+Name()+" is starting....",5) )
-	throw TError("(%s) Arhive <%s> no started!",NAME_MODUL, Name().c_str());
+    if( SYS->event_wait( run_st, true, string(MOD_ID)+": Task of message arhiv "+name()+" is starting....",5) )
+	throw TError("(%s) Archive <%s> no started!",MOD_ID, name().c_str());
 }
 
-void TMessArh::stop()
+void TMessArch::stop()
 {
-    if(!run_st) throw TError("(%s) Arhive %s already stoped!",NAME_MODUL,Name().c_str());
+    if(!run_st) throw TError("(%s) Archive %s already stoped!",MOD_ID,name().c_str());
     m_endrun = true;
-    SYS->event_wait( run_st, false, string(NAME_MODUL)+": Thread is stoping....");
+    SYS->event_wait( run_st, false, string(MOD_ID)+": Thread is stoping....");
     pthread_join( m_pthr, NULL );
 }
 	    
-void *TMessArh::Task(void *param)
+void *TMessArch::Task(void *param)
 {
     int i_cnt = 0;
-    TMessArh *arh = (TMessArh *)param;
+    TMessArch *arh = (TMessArch *)param;
 
     arh->m_endrun = false;
 
 #if OSC_DEBUG
-    arh->Owner().m_put("DEBUG",MESS_DEBUG,"%s:Thread <%d>!",arh->Name().c_str(),getpid() );
+    arh->owner().mPut("DEBUG",MESS_DEBUG,"%s:Thread <%d>!",arh->name().c_str(),getpid() );
 #endif	
     
     try
@@ -307,7 +295,7 @@ void *TMessArh::Task(void *param)
 	    {
 		i_cnt = 0;
 		try{ arh->ScanDir(); }
-		catch(TError err) { arh->Owner().m_put("SYS",MESS_WARNING,"%s:%s",arh->Name().c_str(),err.what().c_str() ); } 
+		catch(TError err) { arh->owner().mPut("SYS",MESS_WARNING,"%s:%s",arh->name().c_str(),err.what().c_str() ); } 
 	    }
 	}
 	arh->run_st = false;
@@ -315,17 +303,17 @@ void *TMessArh::Task(void *param)
     catch(TError err)
     { 
 	arh->run_st   = false;
-	arh->Owner().m_put("SYS",MESS_CRIT,"%s:%s",arh->Name().c_str(),err.what().c_str()); 
+	arh->owner().mPut("SYS",MESS_CRIT,"%s:%s",arh->name().c_str(),err.what().c_str()); 
     }
 
     return(NULL);
 }
 
-void TMessArh::put( vector<SBufRec> &mess )
+void TMessArch::put( vector<TMessage::SRec> &mess )
 {
     ResAlloc res(m_res,false);
     
-    if(!run_st) throw TError("(%s) No started!",Name().c_str());
+    if(!run_st) throw TError("(%s) No started!",name().c_str());
     for( unsigned i_m = 0; i_m < mess.size(); i_m++)
     {
 	int p_cnt = 0;
@@ -341,7 +329,7 @@ void TMessArh::put( vector<SBufRec> &mess )
 	    res.release();
 	    
 	    res.request(m_res,true);
-	    //Create new arhive
+	    //Create new Archive
 	    time_t tm = time(NULL);
 	    char *c_tm = ctime( &tm );
 	    for( int i_ch = 0; i_ch < strlen(c_tm); i_ch++ )
@@ -349,14 +337,14 @@ void TMessArh::put( vector<SBufRec> &mess )
 	    string AName = m_addr+'/'+c_tm+".msg";
 	    try
 	    {		
-		arh_s.push_back( new TFileArh(  SYS->FixFName(AName), 
+		arh_s.push_back( new TFileArch(  SYS->FixFName(AName), 
 						mess[i_m].time, 
-						mess[i_m].time+((TMArhive &)Owner()).m_mess_time_size*24*60*60, 
+						mess[i_m].time+((TMArchive &)owner()).m_mess_time_size*24*60*60, 
 						this ) );
     	    }
 	    catch(TError err) 
 	    { 
-		Owner().m_put("SYS",MESS_CRIT,"%s:Error create new arhive file <%s>!",Name().c_str(),AName.c_str() ); 
+		owner().mPut("SYS",MESS_CRIT,"%s:Error create new Archive file <%s>!",name().c_str(),AName.c_str() ); 
 		return;
 	    }
 	    res.release();
@@ -367,12 +355,10 @@ void TMessArh::put( vector<SBufRec> &mess )
     }
 }
 
-void TMessArh::get( time_t b_tm, time_t e_tm, vector<SBufRec> &mess, const string &category, char level )
+void TMessArch::get( time_t b_tm, time_t e_tm, vector<TMessage::SRec> &mess, const string &category, char level )
 {
     if( e_tm < b_tm ) return;
-    if(!run_st) throw TError("(%s) No started!",Name().c_str());
-    
-    printf("TEST 00\n");
+    if(!run_st) throw TError("(%s) No started!",name().c_str());
     
     ResAlloc res(m_res,false);
     int p_cnt = 0;
@@ -383,7 +369,7 @@ void TMessArh::get( time_t b_tm, time_t e_tm, vector<SBufRec> &mess, const strin
 	    arh_s[i_arh]->get(b_tm, e_tm, mess, category, level);
 }
 
-void TMessArh::ScanDir()
+void TMessArch::ScanDir()
 {    
     struct stat file_stat;
     dirent *scan_dirent;
@@ -416,7 +402,7 @@ void TMessArh::ScanDir()
 	    if( arh_s[i_arh]->Name() == NameArh ) break;
 	if( i_arh < arh_s.size() )
 	{
-	    //========== Arhive already registred=============
+	    //========== Archive already registred=============
 	    arh_s[i_arh]->scan = true;
 	    arh_s[i_arh]->Sync();
 	    res.release();
@@ -424,17 +410,17 @@ void TMessArh::ScanDir()
 	else
 	{	
 	    res.release();
-	    TFileArh *f_arh = new TFileArh(this);
+	    TFileArch *f_arh = new TFileArch(this);
 	    f_arh->Attach( NameArh );			    
 	    f_arh->scan = true;
-	    //Free used memory for old arhives
+	    //Free used memory for old Archives
 	    if( time(NULL) < f_arh->Begin() || time(NULL) > f_arh->End() ) f_arh->Sync(true);
 	    res.request(m_res,true);
 	    arh_s.push_back( f_arh );		
 	    res.release();
 	}
     }
-    //==== Check deleting arhives ====
+    //==== Check deleting Archives ====
     res.request(m_res,true);
     for( unsigned i_arh = 0; i_arh < arh_s.size(); i_arh++) 
 	if( !arh_s[i_arh]->scan )
@@ -449,36 +435,36 @@ void TMessArh::ScanDir()
 }
 
 //==============================================================================
-//================= BaseArh::TFileArh ==========================================
+//================= BaseArch::TFileArch ========================================
 //==============================================================================
-TFileArh::TFileArh( TMessArh *owner ) : m_owner(owner), scan(false), m_err(false), m_write(false), m_load(false) 
+TFileArch::TFileArch( TMessArch *owner ) : m_owner(owner), scan(false), m_err(false), m_write(false), m_load(false) 
 {
-    m_res = ResAlloc::ResCreate( );
+    m_res = ResAlloc::resCreate( );
 }
 
-TFileArh::TFileArh( const string &name, time_t beg, time_t end, TMessArh *owner ) ://  string charset, int time_size) :
-    m_owner(owner), scan(false), m_err(false), m_write(false), m_load(false)
+TFileArch::TFileArch( const string &name, time_t beg, time_t end, TMessArch *n_owner ) ://  string charset, int time_size) :
+    m_owner(n_owner), scan(false), m_err(false), m_write(false), m_load(false)
 {
     char buf[20];
-    m_res = ResAlloc::ResCreate( );    
+    m_res = ResAlloc::resCreate( );    
     
     //int hd = open( name.c_str(),O_RDWR|O_CREAT|O_TRUNC, S_IWRITE|S_IREAD );
     int hd = open( name.c_str(),O_RDWR|O_CREAT|O_TRUNC, SYS->cr_file_perm() );
-    if(hd <= 0) throw TError("%s: Can not create file: %s!"NAME_MODUL,name.c_str());						 
+    if(hd <= 0) throw TError("%s: Can not create file: %s!"MOD_ID,name.c_str());						 
 
-    m_node.new_xml();
-    m_node.set_name(NAME_MODUL);
-    m_node.set_attr("Version",VERSION,true);
-    m_node.set_attr("Charset",((TMArhive &)Owner().Owner()).m_mess_charset,true);
+    m_node.clean();
+    m_node.name(MOD_ID);
+    m_node.attr("Version",VERSION,true);
+    m_node.attr("Charset",((TMArchive &)owner().owner()).m_mess_charset,true);
     snprintf(buf,sizeof(buf),"%X",beg);
-    m_node.set_attr("Begin",buf,true);
+    m_node.attr("Begin",buf,true);
     snprintf(buf,sizeof(buf),"%X",end);
-    m_node.set_attr("End",buf,true);
-    string x_cf = m_node.get_xml(true);
+    m_node.attr("End",buf,true);
+    string x_cf = m_node.save(true);
     write(hd,x_cf.c_str(),x_cf.size());	
     close(hd);    
     m_name  = name;
-    m_chars = m_node.get_attr("Charset");
+    m_chars = m_node.attr("Charset");
     m_err   = false;
     m_write = false;
     m_load  = true;
@@ -486,14 +472,14 @@ TFileArh::TFileArh( const string &name, time_t beg, time_t end, TMessArh *owner
     m_end   = end;    
 }
 
-TFileArh::~TFileArh()
+TFileArch::~TFileArch()
 {
     Sync(); 
     
-    ResAlloc::ResDelete( m_res );       
+    ResAlloc::resDelete( m_res );       
 }
 
-void TFileArh::Attach( const string &name )
+void TFileArch::Attach( const string &name )
 {
     ResAlloc res(m_res,true);
     
@@ -512,16 +498,16 @@ void TFileArh::Attach( const string &name )
 	free(buf);
 	try
 	{
-	    m_node.load_xml(s_buf);
-	    if( m_node.get_name() != NAME_MODUL ) 
+	    m_node.load(s_buf);
+	    if( m_node.name() != MOD_ID ) 
     	    { 
-		Owner().Owner().m_put("SYS",MESS_ERR,"%s:No my arhive file: %s",Owner().Name().c_str(),name.c_str()); 
+		owner().owner().mPut("SYS",MESS_ERR,"%s:No my Archive file: %s",owner().name().c_str(),name.c_str()); 
 		m_err = true; 
 	    }
 	}
 	catch( TError err )
 	{ 
-	    Owner().Owner().m_put("SYS",MESS_ERR,"%s:%s",Owner().Name().c_str(),err.what().c_str()); 
+	    owner().owner().mPut("SYS",MESS_ERR,"%s:%s",owner().name().c_str(),err.what().c_str()); 
 	    m_err = true; 
 	}
     }
@@ -529,67 +515,64 @@ void TFileArh::Attach( const string &name )
     if( !m_err )
     {
 	m_write = false;
-	m_chars = m_node.get_attr("Charset");
-	m_beg = strtol( m_node.get_attr("Begin").c_str(),(char **)NULL,16);
-	m_end = strtol( m_node.get_attr("End").c_str(),(char **)NULL,16); 
+	m_chars = m_node.attr("Charset");
+	m_beg = strtol( m_node.attr("Begin").c_str(),(char **)NULL,16);
+	m_end = strtol( m_node.attr("End").c_str(),(char **)NULL,16); 
 	m_load = true;
     	m_acces = time(NULL);
     }
-    else m_node.new_xml();
+    else m_node.clean();
 }
 
-void TFileArh::put( SBufRec mess )
+void TFileArch::put( TMessage::SRec mess )
 {    
-    if( m_err ) throw TError("%s: Put message to error arhive file!",NAME_MODUL);
+    if( m_err ) throw TError("%s: Put message to error Archive file!",MOD_ID);
     if( !m_load )
     {
 	Attach( m_name ); 
 	if( m_err || !m_load )
-	    throw TError("%s: Arhive file isn't attaching!",NAME_MODUL);
+	    throw TError("%s: Archive file isn't attaching!",MOD_ID);
     }
     
     ResAlloc res(m_res,true);
 
     // Want of make checking time into file         //!!!!
     unsigned i_ch;	    
-    for( unsigned i_ch = 0; i_ch < m_node.get_child_count(); i_ch++)
-	if( strtol( m_node.get_child(i_ch)->get_attr("tm").c_str(),(char **)NULL,16) > mess.time )
+    for( unsigned i_ch = 0; i_ch < m_node.childSize(); i_ch++)
+	if( strtol( m_node.childGet(i_ch)->attr("tm").c_str(),(char **)NULL,16) > mess.time )
 	    break;  
 	
     char buf[20];    
-    XMLNode *cl_node = m_node.ins_child(i_ch,"m");
+    XMLNode *cl_node = m_node.childIns(i_ch,"m");
     snprintf(buf,sizeof(buf),"%X",mess.time);
-    cl_node->set_attr("tm",buf,true);
+    cl_node->attr("tm",buf,true);
     snprintf(buf,sizeof(buf),"%d",mess.level);
-    cl_node->set_attr("lv",buf,true);
-    cl_node->set_attr("cat",mess.categ,true);
-    string message = mess.mess;
-    Mess->SconvOut(m_chars, message);
-    cl_node->set_text(message);	    
+    cl_node->attr("lv",buf,true);
+    cl_node->attr("cat",mess.categ,true);
+    cl_node->text(Mess->SconvOut(m_chars, mess.mess));	    
     m_write = true;
     m_acces = time(NULL);
 }
 
-void TFileArh::get( time_t b_tm, time_t e_tm, vector<SBufRec> &mess, const string &category, char level )
+void TFileArch::get( time_t b_tm, time_t e_tm, vector<TMessage::SRec> &mess, const string &category, char level )
 {
-    if( m_err ) throw TError("%s: Put message to error arhive file!",NAME_MODUL);
+    if( m_err ) throw TError("%s: Put message to error Archive file!",MOD_ID);
     if( !m_load )
     {
 	Attach( m_name ); 
 	if( m_err || !m_load )
-	    throw TError("%s: Arhive file isn't attaching!",NAME_MODUL);
+	    throw TError("%s: Archive file isn't attaching!",MOD_ID);
     }
     
     ResAlloc res(m_res,false);
-    for( unsigned i_ch = 0; i_ch < m_node.get_child_count(); i_ch++)
+    for( unsigned i_ch = 0; i_ch < m_node.childSize(); i_ch++)
     {
 	//find messages
-	SBufRec b_rec;
-        b_rec.time  = strtol( m_node.get_child(i_ch)->get_attr("tm").c_str(),(char **)NULL,16);
-        b_rec.categ = m_node.get_child(i_ch)->get_attr("cat");
-        b_rec.level = atoi( m_node.get_child(i_ch)->get_attr("lv").c_str() );
-	b_rec.mess  = m_node.get_child(i_ch)->get_text();
-    	Mess->SconvIn(m_chars, b_rec.mess);
+	TMessage::SRec b_rec;
+        b_rec.time  = strtol( m_node.childGet(i_ch)->attr("tm").c_str(),(char **)NULL,16);
+        b_rec.categ = m_node.childGet(i_ch)->attr("cat");
+        b_rec.level = atoi( m_node.childGet(i_ch)->attr("lv").c_str() );
+	b_rec.mess  = Mess->SconvIn(m_chars, m_node.childGet(i_ch)->text() );
 	if( b_rec.time >= b_tm && b_rec.time < e_tm && (b_rec.categ == category || category == "") && b_rec.level >= level )
 	{
 	    //Find message dublicates
@@ -606,7 +589,7 @@ void TFileArh::get( time_t b_tm, time_t e_tm, vector<SBufRec> &mess, const strin
     m_acces = time(NULL);
 }
 
-void TFileArh::Sync( bool free )
+void TFileArch::Sync( bool free )
 {
     ResAlloc res(m_res,true);
     if( !m_err && m_load )
@@ -616,16 +599,16 @@ void TFileArh::Sync( bool free )
 	    int hd = open( m_name.c_str(),O_RDWR|O_TRUNC );
 	    if(hd > 0 ) 
 	    {
-		string x_cf = m_node.get_xml(true);
+		string x_cf = m_node.save(true);
 		write(hd,x_cf.c_str(),x_cf.size());    
 		close(hd);
 		m_write = false;
 	    }
 	}
 	// Free memory after 10 minets
-	if( time(NULL) > m_acces + ((TMArhive &)Owner().Owner()).m_mess_timeout_free*60 || free )
+	if( time(NULL) > m_acces + ((TMArchive &)owner().owner()).m_mess_timeout_free*60 || free )
 	{
-	    m_node.new_xml();
+	    m_node.clean();
 	    m_load = false;
 	}
     }    
