@@ -30,16 +30,18 @@
 #include <tkernel.h>
 #include <tmessage.h>
 #include <ttransports.h>
+#include <ttiparam.h>
 #include <tcontrollers.h>
 #include "sys.h"
 
 //============ Modul info! =====================================================
-#define NAME_MODUL  "SysContr"
-#define NAME_TYPE   "Controller"
+#define MOD_ID      "SysContr"
+#define MOD_NAME    "System controller"
+#define MOD_TYPE    "Controller"
 #define VER_TYPE    VER_CNTR
-#define VERSION     "0.5.0"
+#define VERSION     "0.6.0"
 #define AUTORS      "Roman Savochenko"
-#define DESCRIPTION "System controller used for monitoring and control OS"
+#define DESCRIPTION "Allow system controller. System controller want for monitoring and control OS"
 #define LICENSE     "GPL"
 //==============================================================================
 
@@ -49,27 +51,27 @@
 
 extern "C"
 {
-    SAtMod module( int n_mod )
+    TModule::SAt module( int n_mod )
     {
-	SAtMod AtMod;
+	TModule::SAt AtMod;
 
 	if(n_mod==0)
 	{
-	    AtMod.name  = NAME_MODUL;
-	    AtMod.type  = NAME_TYPE;
+	    AtMod.id	= MOD_ID;
+	    AtMod.type  = MOD_TYPE;
 	    AtMod.t_ver = VER_TYPE;
 	}
 	else
-    	    AtMod.name  = "";
+    	    AtMod.id	= "";
 
 	return( AtMod );
     }
 
-    TModule *attach( const SAtMod &AtMod, const string &source )
+    TModule *attach( const TModule::SAt &AtMod, const string &source )
     {
 	SystemCntr::TTpContr *self_addr = NULL;
 
-    	if( AtMod.name == NAME_MODUL && AtMod.type == NAME_TYPE && AtMod.t_ver == VER_TYPE )
+    	if( AtMod.id == MOD_ID && AtMod.type == MOD_TYPE && AtMod.t_ver == VER_TYPE )
 	    self_addr = new SystemCntr::TTpContr( source );
 
 	return ( self_addr );
@@ -84,13 +86,14 @@ using namespace SystemCntr;
 
 TTpContr::TTpContr( string name )  
 {
-    NameModul = NAME_MODUL;
-    NameType  = NAME_TYPE;
-    Vers      = VERSION;
-    Autors    = AUTORS;
-    DescrMod  = DESCRIPTION;
-    License   = LICENSE;
-    Source    = name;    
+    mId 	= MOD_ID;
+    mName       = MOD_NAME;
+    mType  	= MOD_TYPE;
+    Vers      	= VERSION;
+    Autors    	= AUTORS;
+    DescrMod  	= DESCRIPTION;
+    License   	= LICENSE;
+    Source    	= name;    
 }
 
 TTpContr::~TTpContr()
@@ -98,22 +101,26 @@ TTpContr::~TTpContr()
 
 }
 
-void TTpContr::pr_opt_descr( FILE * stream )
+string TTpContr::optDescr( )
 {
-    fprintf(stream,
-    "==================== Module %s options =======================\n"
-    "------------------ Fields <%s> sections of config file --------------\n"
-    "\n",NAME_MODUL,NAME_MODUL);
+    char buf[STR_BUF_LEN];
+
+    snprintf(buf,sizeof(buf),I18N(
+	"======================= The module <%s:%s> options =======================\n"
+	"---------- Parameters of the module section <%s> in config file ----------\n\n"),
+	MOD_TYPE,MOD_ID,MOD_ID);
+    
+    return(buf);
 }
 
-
-void TTpContr::mod_CheckCommandLine( )
+void TTpContr::modCheckCommandLine( )
 {
     int next_opt;
     char *short_opt="h";
     struct option long_opt[] =
     {
-	{NULL        ,0,NULL,0  }
+	{"help"    ,0,NULL,'h'},
+	{NULL      ,0,NULL,0  }
     };
 
     optind=opterr=0;
@@ -122,38 +129,31 @@ void TTpContr::mod_CheckCommandLine( )
 	next_opt=getopt_long(SYS->argc,(char * const *)SYS->argv,short_opt,long_opt,NULL);
 	switch(next_opt)
 	{
-	    case 'h': pr_opt_descr(stdout); break;
+	    case 'h': fprintf(stdout,optDescr().c_str()); break;
 	    case -1 : break;
 	}
     } while(next_opt != -1);
 }
 
-void TTpContr::mod_UpdateOpt( )
+void TTpContr::modUpdateOpt( )
 {
 
 }
 
-void TTpContr::mod_connect( )
+void TTpContr::modConnect( )
 {    
-    TModule::mod_connect( );
-    //==== Desribe controler's bd fields ====
-    SFld elem[] =         
-    {    
-	{PRM_B_All ,I18N("System parameteres table"),T_STRING,"system","30"},
-	{"PERIOD"  ,I18N("The request period (ms)") ,T_DEC   ,"1000"  ,"5" ,"0;10000"}
-    };
-    LoadCfg(elem,sizeof(elem)/sizeof(SFld));
-    
-    SFld elemPrm[] =         
-    {
-	{"TYPE" ,I18N("System part") ,T_DEC|T_SELECT|V_NOVAL|F_PREV       ,"0","2","3;4;2;0;1",
-	    (I18Ns("CPU")+";"+I18Ns("Memory")+";"+I18Ns("Up time")+";"+I18Ns("Hdd temperature")+";"+I18Ns("Sensors")).c_str()},
-	{"SUBT" ,""                  ,T_DEC|T_SELECT|V_NOVAL|F_PREV|F_SELF,"" ,"2"}
-    };
-    LoadTpParmCfg(AddTpParm(PRM_All,PRM_B_All,I18N("All parameters")),elemPrm,sizeof(elemPrm)/sizeof(SFld));
+    TModule::modConnect( );
+    //==== Controler's bd structure ====    
+    fldAdd( new TFld(PRM_B_All,I18N("System parameteres table"),T_STRING,"30","system") );
+    fldAdd( new TFld("PERIOD",I18N("The request period (ms)"),T_DEC,"5","1000","0;10000") );
+    //==== Parameter type bd structure ====
+    int t_prm = tpParmAdd(PRM_All,PRM_B_All,I18N("All parameters"));
+    tpPrmAt(t_prm).fldAdd( new TFld("TYPE",I18N("System part"),T_DEC|T_SELECT|F_NOVAL|F_PREV,"2","0","3;4;2;0;1",
+	I18Ns("CPU")+";"+I18Ns("Memory")+";"+I18Ns("Up time")+";"+I18Ns("Hdd temperature")+";"+I18Ns("Sensors")) );
+    tpPrmAt(t_prm).fldAdd( new TFld("SUBT" ,"",T_DEC|T_SELECT|F_NOVAL|F_PREV|F_SELF,"2") );
 }
 
-TController *TTpContr::ContrAttach( const string &name, const SBDS &bd)
+TController *TTpContr::ContrAttach( const string &name, const TBDS::SName &bd)
 {
     return( new TMdContr(name,bd,this,this));    
 }
@@ -162,7 +162,7 @@ TController *TTpContr::ContrAttach( const string &name, const SBDS &bd)
 //==== TMdContr 
 //======================================================================
 
-TMdContr::TMdContr( string name_c, const SBDS &bd, ::TTipController *tcntr, ::TElem *cfgelem) :
+TMdContr::TMdContr( string name_c, const TBDS::SName &bd, ::TTipController *tcntr, ::TElem *cfgelem) :
 	::TController(name_c,bd,tcntr,cfgelem), endrun(false), period(cfg("PERIOD").getI())
 {    
 
@@ -170,25 +170,25 @@ TMdContr::TMdContr( string name_c, const SBDS &bd, ::TTipController *tcntr, ::TE
 
 TMdContr::~TMdContr()
 {
-    if( run_st ) Stop();
+    if( run_st ) stop();
 }
 
 TParamContr *TMdContr::ParamAttach( const string &name, int type )
 {    
-    return(new TMdPrm(name,&Owner().at_TpPrm(type),this));
+    return(new TMdPrm(name,&owner().tpPrmAt(type),this));
 }
 
-void TMdContr::Load_( )
+void TMdContr::load_( )
 {
 
 }
 
-void TMdContr::Save_( )
+void TMdContr::save_( )
 {
 
 }
 
-void TMdContr::Start_( )
+void TMdContr::start_( )
 {      
     pthread_attr_t      pthr_attr;
     struct sched_param  prior;
@@ -199,29 +199,29 @@ void TMdContr::Start_( )
     {
 	list(list_p);
 	for(unsigned i_prm=0; i_prm < list_p.size(); i_prm++)
-	    p_hd.push_back( att(list_p[i_prm],Name()+"_start") );
+	    p_hd.push_back( at(list_p[i_prm],name()+"_start") );
 	//---------------------------------------
 	pthread_attr_init(&pthr_attr);
 	pthread_attr_setschedpolicy(&pthr_attr,SCHED_OTHER);
 	pthread_create(&pthr_tsk,&pthr_attr,Task,this);
 	pthread_attr_destroy(&pthr_attr);
-	if( SYS->event_wait( run_st, true, string(NAME_MODUL)+": Controller "+Name()+" is starting....",5) )
-	    throw TError("%s: Controller %s no started!",NAME_MODUL,Name().c_str());
+	if( SYS->event_wait( run_st, true, string(MOD_ID)+": Controller "+name()+" is starting....",5) )
+	    throw TError("%s: Controller %s no started!",MOD_ID,name().c_str());
     }    
 }
 
-void TMdContr::Stop_( )
+void TMdContr::stop_( )
 {  
     if( run_st )
     {
 	endrun = true;
 	pthread_kill(pthr_tsk, SIGALRM);
-	if( SYS->event_wait( run_st, false, string(NAME_MODUL)+": Controller "+Name()+" is stoping....",5) )
-	    throw TError("%s: Controller %s no stoped!",NAME_MODUL,Name().c_str());
+	if( SYS->event_wait( run_st, false, string(MOD_ID)+": Controller "+name()+" is stoping....",5) )
+	    throw TError("%s: Controller %s no stoped!",MOD_ID,name().c_str());
 	pthread_join(pthr_tsk, NULL);
 
-    	for(unsigned i_prm=0; i_prm < p_hd.size(); i_prm++)
-	    det( p_hd[i_prm] );
+    	//for(unsigned i_prm=0; i_prm < p_hd.size(); i_prm++)
+	//    det( p_hd[i_prm] );
     	p_hd.clear();
     }
 } 
@@ -232,7 +232,7 @@ void *TMdContr::Task(void *contr)
     TMdContr *cntr = (TMdContr *)contr;
 
 #if OSC_DEBUG
-    cntr->Owner().m_put("DEBUG",MESS_DEBUG,"%s: Thread <%d>!",cntr->Name().c_str(),getpid() );
+    cntr->owner().mPut("DEBUG",MESS_DEBUG,"%s: Thread <%d>!",cntr->name().c_str(),getpid() );
 #endif
 
     if(cntr->period == 0) return(NULL);
@@ -246,7 +246,7 @@ void *TMdContr::Task(void *contr)
     while( !cntr->endrun )
     {
 	for(unsigned i_p=0; i_p < cntr->p_hd.size(); i_p++)
-	    ((TMdPrm &)cntr->at(cntr->p_hd[i_p])).getVal();
+	    cntr->p_hd[i_p].at().getVal();
 	pause();
     }
     cntr->run_st = false;
@@ -261,7 +261,7 @@ void *TMdContr::Task(void *contr)
 TMdPrm::TMdPrm( string name, TTipParam *tp_prm, TController *contr) : 
     TParamContr(name,tp_prm,contr), m_type(PRM_NONE)
 {        
-    cfg("TYPE").setSEL(Owner().Owner().I18N("CPU"));
+    cfg("TYPE").setSEL(owner().owner().I18N("CPU"));
 }
 
 TMdPrm::~TMdPrm( )
@@ -311,16 +311,16 @@ void TMdPrm::setType( char tp )
     }catch(TError err) { m_type = PRM_NONE; }
 }
 
-bool TMdPrm::cfChange( TCfg &i_cfg )
+bool TMdPrm::change( TCfg &i_cfg )
 {        
     //Change TYPE parameter
     if( i_cfg.name() == "TYPE" )
     {
-	if( i_cfg.getSEL() == Owner().Owner().I18N("CPU") ) 			setType( PRM_CPU );
-	else if( i_cfg.getSEL() == Owner().Owner().I18N("Memory") ) 		setType( PRM_MEM );
-	else if( i_cfg.getSEL() == Owner().Owner().I18N("Up time") ) 		setType( PRM_UPTIME );
-	else if( i_cfg.getSEL() == Owner().Owner().I18N("Hdd temperature") ) 	setType( PRM_HDDT );
-	else if( i_cfg.getSEL() == Owner().Owner().I18N("Sensors") )    	setType( PRM_SENSOR );
+	if( i_cfg.getSEL() == owner().owner().I18N("CPU") ) 			setType( PRM_CPU );
+	else if( i_cfg.getSEL() == owner().owner().I18N("Memory") ) 		setType( PRM_MEM );
+	else if( i_cfg.getSEL() == owner().owner().I18N("Up time") ) 		setType( PRM_UPTIME );
+	else if( i_cfg.getSEL() == owner().owner().I18N("Hdd temperature") ) 	setType( PRM_HDDT );
+	else if( i_cfg.getSEL() == owner().owner().I18N("Sensors") )    	setType( PRM_SENSOR );
 	else return(false);
        	return(true);       
     }    
@@ -341,25 +341,22 @@ bool TMdPrm::cfChange( TCfg &i_cfg )
 //==== HddTemp
 //======================================================================
 Hddtemp::Hddtemp( TMdPrm &mprm ) : TElem("hddtemp"),
-    prm(mprm), tr( mprm.Owner().Owner().Owner().Owner().Transport() ),
-    t_tr("socket"),n_tr("tr_"+mprm.Name()), c_subt(prm.cfg("SUBT")), err_st(false)
+    prm(mprm), tr( mprm.owner().owner().owner().owner().Transport() ),
+    t_tr("socket"),n_tr("tr_"+mprm.name()), c_subt(prm.cfg("SUBT")), err_st(false)
 {
-    ((TTipTransport &)tr.gmd_at(t_tr).at()).out_add(n_tr);
+    ((TTipTransport &)tr.gmdAt(t_tr).at()).outAdd(n_tr);
     otr = new AutoHD<TTransportOut>;
-    *otr = (((TTipTransport &)tr.gmd_at(t_tr).at()).out_at(n_tr));
+    *otr = (((TTipTransport &)tr.gmdAt(t_tr).at()).outAt(n_tr));
     
-    otr->at().lName() = prm.Owner().Owner().I18N("Parametr Hddtemp");
-    otr->at().addres() = "TCP:127.0.0.1:7634";
+    otr->at().lName() = prm.owner().owner().I18N("Parametr Hddtemp");
+    otr->at().address() = "TCP:127.0.0.1:7634";
     otr->at().start();
     
-    SFld valE[] =
-    {
-	{"disk" ,prm.Owner().Owner().I18N("Name")        ,T_STRING|F_NWR,"" ,"" },
-	{"ed"   ,prm.Owner().Owner().I18N("Measure unit"),T_STRING|F_NWR,"" ,"" },
-	{"value",prm.Owner().Owner().I18N("Temperature") ,T_DEC   |F_NWR,"0","3"}	
-    };
-    for( unsigned i_el = 0; i_el < sizeof(valE)/sizeof(SFld); i_el++ )
-	elAdd(&valE[i_el]);    
+    //HDD value structure
+    fldAdd( new TFld("disk",prm.owner().owner().I18N("Name"),T_STRING|F_NWR) );
+    fldAdd( new TFld("ed",prm.owner().owner().I18N("Measure unit"),T_STRING|F_NWR) );
+    fldAdd( new TFld("value",prm.owner().owner().I18N("Temperature"),T_DEC|F_NWR,"3","0") );    
+    
     prm.vlAttElem( this );
     // Make direct access
     atrb.push_back(prm.vlAt("disk"));
@@ -370,7 +367,7 @@ Hddtemp::Hddtemp( TMdPrm &mprm ) : TElem("hddtemp"),
 Hddtemp::~Hddtemp()
 {
     delete otr;    
-    ((TTipTransport &)tr.gmd_at(t_tr).at()).out_del(n_tr);
+    ((TTipTransport &)tr.gmdAt(t_tr).at()).outDel(n_tr);
     atrb.clear();
     prm.vlDetElem( this );
 }
@@ -378,16 +375,16 @@ Hddtemp::~Hddtemp()
 void Hddtemp::init()
 {
     //Create Config
-    c_subt.fld().descr() = prm.Owner().Owner().I18N("Disk");
-    c_subt.fld().val_i().clear();
-    c_subt.fld().nSel().clear();    
+    c_subt.fld().descr() = prm.owner().owner().I18N("Disk");
+    c_subt.fld().selValI().clear();
+    c_subt.fld().selNm().clear();    
 
     vector<string> list;
     dList(list);
     for( int i_l = 0; i_l < list.size(); i_l++ )
     {
-	c_subt.fld().val_i().push_back(i_l);
-	c_subt.fld().nSel().push_back(list[i_l]);
+	c_subt.fld().selValI().push_back(i_l);
+	c_subt.fld().selNm().push_back(list[i_l]);
     }
     if( list.size() ) c_subt.setSEL(list[0]);    
 }
@@ -399,12 +396,12 @@ void Hddtemp::dList( vector<string> &list )
     string val;
     try 
     { 
-	len = otr->at().IOMess("1",1,buf,sizeof(buf),1); buf[len] = '\0';	
+	len = otr->at().messIO("1",1,buf,sizeof(buf),1); buf[len] = '\0';	
 	err_st = false;	
 	val.append(buf,len);
 	while( len == sizeof(buf) )
 	{
-	    len = otr->at().IOMess(NULL,0,buf,sizeof(buf),1); buf[len] = '\0';
+	    len = otr->at().messIO(NULL,0,buf,sizeof(buf),1); buf[len] = '\0';
 	    val.append(buf,len);
 	}
 	
@@ -427,7 +424,7 @@ void Hddtemp::dList( vector<string> &list )
     }
     catch( TError err ) 
     { 
-	if( !err_st ) prm.Owner().Owner().m_put("SYS",MESS_ERR,"Error %s\n",err.what().c_str()); 
+	if( !err_st ) prm.owner().owner().mPut("SYS",MESS_ERR,"Error %s\n",err.what().c_str()); 
 	err_st = true;
     }
 }
@@ -441,12 +438,12 @@ void Hddtemp::getVal(  )
     { 
        	string dev =  c_subt.getSEL();
 	
-	len = otr->at().IOMess("1",1,buf,sizeof(buf),1);
+	len = otr->at().messIO("1",1,buf,sizeof(buf),1);
 	err_st = false;
 	val.append(buf,len);
 	while( len == sizeof(buf) )
 	{
-	    len = otr->at().IOMess(NULL,0,buf,sizeof(buf),1);
+	    len = otr->at().messIO(NULL,0,buf,sizeof(buf),1);
 	    val.append(buf,len);
 	}
 
@@ -482,7 +479,7 @@ void Hddtemp::getVal(  )
     }    
     catch( TError err ) 
     {
-	if( !err_st ) prm.Owner().Owner().m_put("SYS",MESS_ERR,"Error %s\n",err.what().c_str()); 
+	if( !err_st ) prm.owner().owner().mPut("SYS",MESS_ERR,"Error %s\n",err.what().c_str()); 
 	err_st = true;
     }
 }
@@ -497,12 +494,9 @@ void Hddtemp::chSub( )
 //======================================================================
 Lmsensors::Lmsensors( TMdPrm &mprm ) : TElem("sensor"), prm(mprm), s_path("/proc/sys/dev/sensors/")
 {
-    SFld valE[] =
-    {
-	{"value","",T_REAL|F_NWR,"0","8.2"}
-    };
-    for( unsigned i_el = 0; i_el < sizeof(valE)/sizeof(SFld); i_el++ )
-	elAdd(&valE[i_el]);
+    //Sensors value structure
+    fldAdd( new TFld("value","",T_REAL|F_NWR,"8.2","0") );
+    
     prm.vlAttElem( this );
 }
 
@@ -515,16 +509,16 @@ void Lmsensors::init()
 {
     TCfg &c_subt = prm.cfg("SUBT");
     //Create config
-    c_subt.fld().descr() = prm.Owner().Owner().I18N("Sensor");
-    c_subt.fld().val_i().clear();
-    c_subt.fld().nSel().clear();
+    c_subt.fld().descr() = prm.owner().owner().I18N("Sensor");
+    c_subt.fld().selValI().clear();
+    c_subt.fld().selNm().clear();
     
     vector<string> list;
     dList(list);
     for( int i_l = 0; i_l < list.size(); i_l++ )
     {
-	c_subt.fld().val_i().push_back(i_l);
-	c_subt.fld().nSel().push_back(list[i_l]);
+	c_subt.fld().selValI().push_back(i_l);
+	c_subt.fld().selNm().push_back(list[i_l]);
     }
     if( list.size() ) c_subt.setSEL(list[0]);        
 }
@@ -598,11 +592,11 @@ void Lmsensors::chSub( )
     string sens =  c_subt.getSEL();
     sens = sens.substr(sens.find("/",0)+1);
     if( sens.find("temp",0) == 0 )
-       	prm.vlAt("value").at().fld().descr() = prm.Owner().Owner().I18N("Temperature");
+       	prm.vlAt("value").at().fld().descr() = prm.owner().owner().I18N("Temperature");
     else if( sens.find("fan",0) == 0 )
-       	prm.vlAt("value").at().fld().descr() = prm.Owner().Owner().I18N("Fan turns");
+       	prm.vlAt("value").at().fld().descr() = prm.owner().owner().I18N("Fan turns");
     else if( sens.find("in",0) == 0 )
-       	prm.vlAt("value").at().fld().descr() = prm.Owner().Owner().I18N("Voltage");
+       	prm.vlAt("value").at().fld().descr() = prm.owner().owner().I18N("Voltage");
 }
 
 //======================================================================
@@ -611,16 +605,14 @@ void Lmsensors::chSub( )
 UpTime::UpTime( TMdPrm &mprm ) : TElem("uptime"), prm(mprm)
 {
     st_tm = time(NULL);
-    SFld valE[] =
-    {
-	{"value",prm.Owner().Owner().I18N("Full seconds"),T_DEC|F_NWR,"0","5"},
-	{"sec"  ,prm.Owner().Owner().I18N("Seconds")     ,T_DEC|F_NWR,"0","2"},
-	{"min"  ,prm.Owner().Owner().I18N("Minutes")     ,T_DEC|F_NWR,"0","2"},
-	{"hour" ,prm.Owner().Owner().I18N("Hours")       ,T_DEC|F_NWR,"0","2"},
-	{"day"  ,prm.Owner().Owner().I18N("Days")        ,T_DEC|F_NWR,"0"}
-    };
-    for( unsigned i_el = 0; i_el < sizeof(valE)/sizeof(SFld); i_el++ )
-	elAdd(&valE[i_el]);
+    
+    //Uptime value structure
+    fldAdd( new TFld("value",prm.owner().owner().I18N("Full seconds"),T_DEC|F_NWR,"","0") );
+    fldAdd( new TFld("sec",prm.owner().owner().I18N("Seconds"),T_DEC|F_NWR,"2","0") );
+    fldAdd( new TFld("min",prm.owner().owner().I18N("Minutes"),T_DEC|F_NWR,"2","0") );
+    fldAdd( new TFld("hour",prm.owner().owner().I18N("Hours"),T_DEC|F_NWR,"2","0") );
+    fldAdd( new TFld("day",prm.owner().owner().I18N("Days"),T_DEC|F_NWR,"","0") );   
+    
     prm.vlAttElem( this );
 }
 
@@ -634,11 +626,11 @@ void UpTime::init()
     //Create config
     TCfg &c_subt = prm.cfg("SUBT");
     c_subt.fld().descr() = "";
-    c_subt.fld().val_i().clear();
-    c_subt.fld().nSel().clear();
+    c_subt.fld().selValI().clear();
+    c_subt.fld().selNm().clear();
     
-    c_subt.fld().val_i().push_back(0); c_subt.fld().nSel().push_back(prm.Owner().Owner().I18N("System"));
-    c_subt.fld().val_i().push_back(1); c_subt.fld().nSel().push_back(prm.Owner().Owner().I18N("Station"));
+    c_subt.fld().selValI().push_back(0); c_subt.fld().selNm().push_back(prm.owner().owner().I18N("System"));
+    c_subt.fld().selValI().push_back(1); c_subt.fld().selNm().push_back(prm.owner().owner().I18N("Station"));
     c_subt.setI(0);        
 }
 
@@ -667,17 +659,14 @@ void UpTime::getVal(  )
 //======================================================================
 //==== CPU
 //======================================================================
-CPU::CPU( TMdPrm &mprm ) : TElem("cpu"), prm(mprm), mod(prm.Owner().Owner())
-{    
-    SFld valE[] =
-    {
-	{"value",mod.I18N("Load (%)")  ,T_REAL|F_NWR,"0","4.1"},
-	{"sys"  ,mod.I18N("System (%)"),T_REAL|F_NWR,"0","4.1"},
-	{"user" ,mod.I18N("User (%)")  ,T_REAL|F_NWR,"0","4.1"},
-	{"idle" ,mod.I18N("Idle (%)")  ,T_REAL|F_NWR,"0","4.1"}
-    };
-    for( unsigned i_el = 0; i_el < sizeof(valE)/sizeof(SFld); i_el++ )
-	elAdd(&valE[i_el]);
+CPU::CPU( TMdPrm &mprm ) : TElem("cpu"), prm(mprm), mod(prm.owner().owner())
+{   
+    //CPU value structure
+    fldAdd( new TFld("value",mod.I18N("Load (%)"),T_REAL|F_NWR,"4.1","0") );
+    fldAdd( new TFld("sys",mod.I18N("System (%)"),T_REAL|F_NWR,"4.1","0") );
+    fldAdd( new TFld("user",mod.I18N("User (%)"),T_REAL|F_NWR,"4.1","0") );
+    fldAdd( new TFld("idle",mod.I18N("Idle (%)"),T_REAL|F_NWR,"4.1","0") );
+    
     prm.vlAttElem( this );
 }
 
@@ -692,10 +681,10 @@ void CPU::init()
     TCfg &t_cf = prm.cfg("SUBT");
     TFld &t_fl = t_cf.fld();
     t_fl.descr() = "";
-    t_fl.val_i().clear();
-    t_fl.nSel().clear();
+    t_fl.selValI().clear();
+    t_fl.selNm().clear();
     
-    t_fl.val_i().push_back(0); t_fl.nSel().push_back(mod.I18N("General"));
+    t_fl.selValI().push_back(0); t_fl.selNm().push_back(mod.I18N("General"));
     
     t_cf.setI(0);        
     //Init start value
@@ -711,8 +700,8 @@ void CPU::init()
 	    cpu.insert(cpu.begin()+n_cpu,gen);
 	    n = fscanf(f,"%d %d %d %d %d\n",&cpu[n_cpu].user,&cpu[n_cpu].nice,&cpu[n_cpu].sys,&cpu[n_cpu].idle,&iowait);
 	    if( n == 6 ) cpu[n_cpu].idle += iowait;
-	    t_fl.val_i().push_back(n_cpu+1);   
-	    t_fl.nSel().push_back(TSYS::int2str(n_cpu));
+	    t_fl.selValI().push_back(n_cpu+1);   
+	    t_fl.selNm().push_back(TSYS::int2str(n_cpu));
 	}	
 	fclose(f);	
     }    
@@ -766,18 +755,15 @@ void CPU::getVal(  )
 //======================================================================
 //==== Memory
 //======================================================================
-Mem::Mem( TMdPrm &mprm ) : TElem("mem"), prm(mprm), mod(prm.Owner().Owner())
+Mem::Mem( TMdPrm &mprm ) : TElem("mem"), prm(mprm), mod(prm.owner().owner())
 {
-    SFld valE[] =
-    {
-	{"value",mod.I18N("Free (kB)")   ,T_DEC|F_NWR,"0"},
-	{"total",mod.I18N("Total (kB)")  ,T_DEC|F_NWR,"0"},
-	{"used" ,mod.I18N("Used (kB)")   ,T_DEC|F_NWR,"0"},
-	{"buff" ,mod.I18N("Buffers (kB)"),T_DEC|F_NWR,"0"},
-	{"cache",mod.I18N("Cached (kB)") ,T_DEC|F_NWR,"0"}
-    };
-    for( unsigned i_el = 0; i_el < sizeof(valE)/sizeof(SFld); i_el++ )
-	elAdd(&valE[i_el]);
+    //Memory value structure
+    fldAdd( new TFld("value",mod.I18N("Free (kB)"),T_DEC|F_NWR,"","0") );
+    fldAdd( new TFld("total",mod.I18N("Total (kB)"),T_DEC|F_NWR,"","0") );
+    fldAdd( new TFld("used",mod.I18N("Used (kB)"),T_DEC|F_NWR,"","0") );
+    fldAdd( new TFld("buff",mod.I18N("Buffers (kB)"),T_DEC|F_NWR,"","0") );
+    fldAdd( new TFld("cache",mod.I18N("Cached (kB)"),T_DEC|F_NWR,"","0") );
+    
     prm.vlAttElem( this );
 }
 
@@ -792,12 +778,12 @@ void Mem::init()
     TCfg &t_cf = prm.cfg("SUBT");
     TFld &t_fl = t_cf.fld();
     t_fl.descr() = "";
-    t_fl.val_i().clear();
-    t_fl.nSel().clear();
+    t_fl.selValI().clear();
+    t_fl.selNm().clear();
     
-    t_fl.val_i().push_back(0); t_fl.nSel().push_back(mod.I18N("All"));
-    t_fl.val_i().push_back(1); t_fl.nSel().push_back(mod.I18N("Phisical"));
-    t_fl.val_i().push_back(2); t_fl.nSel().push_back(mod.I18N("Swap"));
+    t_fl.selValI().push_back(0); t_fl.selNm().push_back(mod.I18N("All"));
+    t_fl.selValI().push_back(1); t_fl.selNm().push_back(mod.I18N("Phisical"));
+    t_fl.selValI().push_back(2); t_fl.selNm().push_back(mod.I18N("Swap"));
     t_cf.setI(0);        
 }
 
@@ -850,22 +836,17 @@ void Mem::chSub()
     int id;
     if( prm.cfg("SUBT").getI() == 2 )
     {
-	try{ id = elNameId("buff"); } catch(...) { return; }
-	elDel(elNameId("buff"));
-	elDel(elNameId("cache"));
+	try{ id = fldId("buff"); } catch(...) { return; }
+	fldDel(fldId("buff"));
+	fldDel(fldId("cache"));
     }
     else
     {
-	try{ id = elNameId("buff"); } 
+	try{ id = fldId("buff"); } 
 	catch(...) 
 	{ 
-	    SFld valE[] =
-	    {
-		{"buff" ,mod.I18N("Buffers (kB)"),T_DEC|F_NWR,"0"},
-		{"cache",mod.I18N("Cached (kB)") ,T_DEC|F_NWR,"0"}
-	    };
-	    for( unsigned i_el = 0; i_el < sizeof(valE)/sizeof(SFld); i_el++ )
-		elAdd(&valE[i_el]);
+	    fldAdd( new TFld("buff",mod.I18N("Buffers (kB)"),T_DEC|F_NWR,"","0") );
+	    fldAdd( new TFld("cache",mod.I18N("Cached (kB)"),T_DEC|F_NWR,"","0") );
 	}
     }    
 }
