@@ -36,13 +36,15 @@
 #include <tvalue.h>
 #include <tparam.h>
 #include <tparams.h>
+#include <ttiparam.h>
 #include "virtual1.h"
 
 //============ Modul info! =====================================================
-#define NAME_MODUL  "virtual_v1"
-#define NAME_TYPE   "Controller"
+#define MOD_ID      "virtual_v1"
+#define MOD_NAME    "Virtual controller"
+#define MOD_TYPE    "Controller"
 #define VER_TYPE    VER_CNTR
-#define VERSION     "0.0.9"
+#define VERSION     "0.0.15"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Virtual controller V1.x (from Complex2) - may be used how internal controller or instrument for GUI"
 #define LICENSE     "GPL"
@@ -60,27 +62,27 @@
 
 extern "C"
 {
-    SAtMod module( int n_mod )
+    TModule::SAt module( int n_mod )
     {
-	SAtMod AtMod;
+	TModule::SAt AtMod;
 
 	if(n_mod==0)
     	{
-	    AtMod.name  = NAME_MODUL;
-	    AtMod.type  = NAME_TYPE;
+	    AtMod.id	= MOD_ID;
+	    AtMod.type  = MOD_TYPE;
 	    AtMod.t_ver = VER_TYPE;
 	}
 	else
-	    AtMod.name  = "";
+	    AtMod.id	= "";
 
 	return( AtMod );
     }
 
-    TModule *attach( const SAtMod &AtMod, const string &source )
+    TModule *attach( const TModule::SAt &AtMod, const string &source )
     {
 	Virtual1::TVirtual *self_addr = NULL;
 
-	if( AtMod.name == NAME_MODUL && AtMod.type == NAME_TYPE && AtMod.t_ver == VER_TYPE )
+	if( AtMod.id == MOD_ID && AtMod.type == MOD_TYPE && AtMod.t_ver == VER_TYPE )
 	    self_addr = new Virtual1::TVirtual( source );
 
 	return ( self_addr );
@@ -93,73 +95,53 @@ using namespace Virtual1;
 //==== TVirtual ======================================================== 
 //======================================================================
 
-
-//=============================================
-//==== Describe ANALOG param struct ===========
-SFld TVirtual::ValAN[] =
+TVirtual::TVirtual( string name ) : 
+    m_frm(""), m_alg(""), algbCfg("./virt_alg.xml"), formCfg("./virt_frm.xml"), NameCfgF("./alg.cfg"), algbs(NULL)
 {
-    {"VAL","Value analog parameter" ,T_REAL,"","10.2"}
-};
-
-//==== Describe DIGIT param struct ===========
-SFld TVirtual::ValDG[] =
-{
-    {"VAL","Value digital parameter",T_BOOL,"","10.2"}
-};
-
-//==== PID regulator ===========
-
-SFld TVirtual::ValPID[] =
-{
-    {"OUT"   ,"Output of regulator"                ,T_REAL        ,"","10.2","0;100"},
-    {"SP"    ,"Setpoint of regulator"              ,T_REAL        ,"","10.2"},
-    {"STAT"  ,"Stat regulator (Manual,Auto,Casc)"  ,T_DEC|T_SELECT,"","1"   ,"0;1;2","Manual;Auto;Cascad"},
-    {"Kp"    ,"Koefficient of proportion"          ,T_REAL        ,"","6.2" ,"-20;20"},
-    {"Ti"    ,"Time of integrated (sek)"           ,T_REAL        ,"","7.2" ,"0;1000"},
-    {"Td"    ,"Time of diff (sek)"                 ,T_REAL        ,"","7.2" ,"0;1000"},
-    {"Tf"    ,"Time of lag (sek)"                  ,T_REAL        ,"","7.2" ,"0;1000"},
-    {"H_UP"  ,"Up out border (%)"                  ,T_REAL        ,"","6.2" ,"0;100"},
-    {"H_DOWN","Down out border (%)"                ,T_REAL        ,"","6.2" ,"0;100"},
-    {"ZN"    ,"Non-sensitive pid error (%)"        ,T_REAL        ,"","5.2" ,"0;20"},
-    {"K1"    ,"Koefficient scale of addon input 1" ,T_REAL        ,"","6.2" ,"-20;20"},
-    {"K2"    ,"Koefficient scale of addon input 2" ,T_REAL        ,"","6.2" ,"-20;20"},
-    {"K3"    ,"Koefficient scale of addon input 3" ,T_REAL        ,"","6.2" ,"-20;20"},
-    {"K4"    ,"Koefficient scale of addon input 4" ,T_REAL        ,"","6.2" ,"-20;20"}
-};
-
-TVirtual::TVirtual( string name ) : NameCfgF("./alg.cfg"), algbs(NULL)
-{
-    NameModul = NAME_MODUL;
-    NameType  = NAME_TYPE;
-    Vers      = VERSION;
-    Autors    = AUTORS;
-    DescrMod  = DESCRIPTION;
-    License   = LICENSE;
-    Source    = name;    
+    mId 	= MOD_ID;
+    mName       = MOD_NAME;
+    mType  	= MOD_TYPE;
+    Vers      	= VERSION;
+    Autors    	= AUTORS;
+    DescrMod  	= DESCRIPTION;
+    License   	= LICENSE;
+    Source    	= name;    
 }
 
 TVirtual::~TVirtual()
 {    
     if(algbs) delete algbs;
+    for( int i_el = 0; i_el < val_el.size(); i_el++)
+	delete val_el[i_el];
 }
 
-void TVirtual::pr_opt_descr( FILE * stream )
+string TVirtual::optDescr( )
 {
-    fprintf(stream,
-    	"======================= %s module options ========================\n"
-	"    --Vrt1CFG=<path>   Set config file name (default ./alg.cfg)\n"
-	"--------------------- Module parameters of config file -------------------\n"
-	"config <path>          path to config file;\n"
-	"\n",NAME_MODUL);
+    char buf[STR_BUF_LEN];
+
+    snprintf(buf,sizeof(buf),I18N(
+        "======================= The module <%s:%s> options =======================\n"
+	"    --Vrt1CFG=<path>   config file name (default ./alg.cfg)\n"
+	"    --Vrt1Alg=<path>   Algoblock's config file (default ./virt_alg.xml)\n"
+	"    --Vrt1Form=<path>  Formul's config file (default ./virt_frm.xml)\n"
+	"---------- Parameters of the module section <%s> in config file ----------\n"
+	"config <path>          config file name (default ./alg.cfg)\n"
+	"alg_cfg <path>         Algoblock's config file (default ./virt_alg.xml)\n"
+	"form_cfg <path>        Formul's config file (default ./virt_frm.xml)\n\n"),
+	MOD_TYPE,MOD_ID,MOD_ID);
+    return(buf);
 }
 
-void TVirtual::mod_CheckCommandLine( )
+void TVirtual::modCheckCommandLine( )
 {
     int next_opt;
     char *short_opt="h";
     struct option long_opt[] =
     {
+	{"help"      ,0,NULL,'h'},
 	{"Vrt1CFG"   ,1,NULL,'c'},
+	{"Vrt1Alg"   ,1,NULL,'a'},
+	{"Vrt1Form"  ,1,NULL,'f'},
 	{NULL        ,0,NULL,0  }
     };
 
@@ -169,82 +151,425 @@ void TVirtual::mod_CheckCommandLine( )
 	next_opt=getopt_long(SYS->argc,(char * const *)SYS->argv,short_opt,long_opt,NULL);
 	switch(next_opt)
 	{
-	    case 'h': pr_opt_descr(stdout); break;
-	    case 'c': NameCfgF = optarg;    break;
+	    case 'h': fprintf(stdout,optDescr().c_str()); break;
+	    case 'c': NameCfgF = optarg;   break;
+	    case 'a': algbCfg = optarg;    break;
+	    case 'f': formCfg = optarg;    break;
 	    case -1 : break;
 	}
     } while(next_opt != -1);
 }
 
-void TVirtual::mod_UpdateOpt( )
+void TVirtual::modUpdateOpt( )
 {
-    try{ NameCfgF = mod_XMLCfgNode()->get_child("id","config")->get_text(); }
-    catch(...) {  }
+    try{ NameCfgF = modCfgNode()->childGet("id","config")->text(); } catch(...) {  }
+    try{ algbCfg = modCfgNode()->childGet("id","alg_cfg")->text(); } catch(...) {  }
+    try{ formCfg = modCfgNode()->childGet("id","form_cfg")->text(); } catch(...) {  }
 }
 
-void TVirtual::mod_connect( )
+void TVirtual::modConnect( )
 {    
-    TModule::mod_connect( );
+    TModule::modConnect( );
+    
+    //Controllers BD structure
+    fldAdd( new TFld(PRM_B_AN,I18N("ANALOG parameteres table"),T_STRING,"30","VRT_AN") );
+    fldAdd( new TFld(PRM_B_DG,I18N("DIGIT parameteres table"),T_STRING,"30","VRT_DG") );
+    fldAdd( new TFld(PRM_B_BLCK,I18N("BLOCK parameteres table"),T_STRING,"30","VRT_BL") );
+    fldAdd( new TFld("PERIOD",I18N("The calc period (ms)"),T_DEC,"5","1000","0;10000") );
+    fldAdd( new TFld("ITER",I18N("The iteration number into calc period"),T_DEC,"2","1","0;99") );
+    fldAdd( new TFld("PER_S",I18N("The sync period (ms)"),T_DEC,"5","1000","0;10000") );
+    
+    //loadCfg(elem,sizeof(elem)/sizeof(SFld));
     
-    //==== Desribe controler's bd fields ====
-    SFld elem[] =         
-    {    
-	{PRM_B_AN  ,I18N("Name of ANALOG parameteres table")     ,T_STRING,"VRT_AN","30"},
-	{PRM_B_DG  ,I18N("Name of DIGIT parameteres table")      ,T_STRING,"VRT_DG","30"},
-	{PRM_B_BLCK,I18N("Name of BLOCK parameteres table")      ,T_STRING,"VRT_BL","30"},
-	{"PERIOD"  ,I18N("The calc period (ms)")                 ,T_DEC   ,"1000"  ,"5" ,"0;10000"},
-	{"ITER"    ,I18N("The iteration number into calc period"),T_DEC   ,"1"     ,"2" ,"0;99"   },
-	{"PER_S"   ,I18N("The sync period (ms)")                 ,T_DEC   ,"1000"  ,"5" ,"0;10000"}
-    };
-    //==== Desribe ANALOG parameter's bd fields ====
-    SFld ElemAN[] =         
-    {
-	{"ED"     ,I18N("Value of measurement")          ,T_STRING         ,""    ,"10"  },
-	{"SCALE"  ,I18N("Scale")                         ,T_DEC|T_SELECT   ,"0"   ,"1"   ,"0;1"           ,I18N("Linear;Square")},
-	{"TIPO"   ,I18N("Type of processing")            ,T_DEC|T_SELECT   ,"0"   ,"1"   ,"0;1;2"         ,I18N("Average;Integrate;Counter")},
-	{"MIN"    ,I18N("Lower scale border")            ,T_REAL           ,"0"   ,"10.2"},
-	{"MAX"    ,I18N("Upper scale border")            ,T_REAL           ,"100" ,"10.2"},
-	{"NTG"    ,I18N("Lower technically scale border"),T_REAL           ,"0"   ,"10.2"},
-	{"VTG"    ,I18N("Upper technically scale border"),T_REAL           ,"0"   ,"10.2"},
-	{"NAG"    ,I18N("Lower alarm scale border")      ,T_REAL           ,"0"   ,"10.2"},
-	{"VAG"    ,I18N("Upper alarm scale border")      ,T_REAL           ,"0"   ,"10.2"},
-	{"Z_GR"   ,I18N("Non-sensitive zone (%)")        ,T_REAL           ,"0.5" ,"4.1" ,"0;50"          },
-	{"TYPE"   ,I18N("The parameter value type")      ,T_STRING|T_SELECT,"A_IN","5"   ,"A_IN;A_OUT;PID",I18N("Input;Output;PID")}
-    };
-    //==== Desribe DIGIT parameter's bd fields ====
-    SFld ElemDG[] =
-    {
-	{"TYPE"   ,I18N("Parameter type"),T_STRING|T_SELECT,"D_IN","5","D_IN;D_OUT",I18N("Input;Output")}
-    };
-    //==== Desribe BLOCK parameter's bd fields ====
-    SFld ElemBL[] =
-    {
-    };
-
-    LoadCfg(elem,sizeof(elem)/sizeof(SFld));
     //Add parameter types
-    LoadTpParmCfg(AddTpParm(PRM_ANALOG,PRM_B_AN  ,I18N("Analog parameter"))           ,ElemAN,sizeof(ElemAN)/sizeof(SFld));
-    LoadTpParmCfg(AddTpParm(PRM_DIGIT ,PRM_B_DG  ,I18N("Digital parameter"))          ,ElemDG,sizeof(ElemDG)/sizeof(SFld));
-    LoadTpParmCfg(AddTpParm(PRM_BLOCK ,PRM_B_BLCK,I18N("Block parameter (algoblock)")),ElemBL,sizeof(ElemBL)/sizeof(SFld));
+    //Analog parameters
+    int t_prm = tpParmAdd(PRM_ANALOG,PRM_B_AN  ,I18N("Analog parameter"));
+    tpPrmAt(t_prm).fldAdd( new TFld("ED",I18N("Value of measurement"),T_STRING,"10") );
+    tpPrmAt(t_prm).fldAdd( new TFld("SCALE",I18N("Scale"),T_DEC|T_SELECT,"1","0","0;1",I18N("Linear;Square")) );
+    tpPrmAt(t_prm).fldAdd( new TFld("TIPO",I18N("Type of processing"),T_DEC|T_SELECT,"1","0","0;1;2",I18N("Average;Integrate;Counter")) );
+    tpPrmAt(t_prm).fldAdd( new TFld("MIN",I18N("Lower scale border"),T_REAL,"10.2","0") );
+    tpPrmAt(t_prm).fldAdd( new TFld("MAX",I18N("Upper scale border"),T_REAL,"10.2","100") );
+    tpPrmAt(t_prm).fldAdd( new TFld("NTG",I18N("Lower technically scale border"),T_REAL,"10.2","0") );
+    tpPrmAt(t_prm).fldAdd( new TFld("VTG",I18N("Upper technically scale border"),T_REAL,"10.2","0") );
+    tpPrmAt(t_prm).fldAdd( new TFld("NAG",I18N("Lower alarm scale border"),T_REAL,"10.2","0") );
+    tpPrmAt(t_prm).fldAdd( new TFld("VAG",I18N("Upper alarm scale border"),T_REAL,"10.2","0") );
+    tpPrmAt(t_prm).fldAdd( new TFld("Z_GR",I18N("Non-sensitive zone (%)"),T_REAL,"4.1","0.5","0;50") );
+    tpPrmAt(t_prm).fldAdd( new TFld("TYPE",I18N("The parameter value type"),T_STRING|T_SELECT,"5","A_IN","A_IN;A_OUT;PID",I18N("Input;Output;PID")) );
+    //Digital parameters
+    t_prm = tpParmAdd(PRM_DIGIT,PRM_B_DG,I18N("Digital parameter"));
+    tpPrmAt(t_prm).fldAdd( new TFld("TYPE",I18N("Parameter type"),T_STRING|T_SELECT,"5","D_IN","D_IN;D_OUT",I18N("Input;Output")) );
+    //Digital parameters
+    t_prm = tpParmAdd(PRM_BLOCK,PRM_B_BLCK,I18N("Block parameter (algoblock)"));
+    
     //Add types of value
-    AddTpVal("A_IN",ValAN ,sizeof(ValAN)/sizeof(SFld));
-    AddTpVal("D_IN",ValDG ,sizeof(ValDG)/sizeof(SFld));
-    AddTpVal("PID" ,ValAN ,sizeof(ValAN)/sizeof(SFld));    
-    AddTpVal("PID" ,ValPID,sizeof(ValPID)/sizeof(SFld));
+    //Analog input
+    TElem *elem = new TElem("A_IN");
+    elem->fldAdd( new TFld("VAL","Value analog parameter",T_REAL,"10.2") );
+    val_el.push_back(elem);
+    //Digital input
+    elem = new TElem("D_IN");
+    elem->fldAdd( new TFld("VAL","Value digital parameter",T_BOOL,"10.2") );
+    val_el.push_back(elem);
+    //PID regulator
+    elem = new TElem("PID");
+    elem->fldAdd( new TFld("VAL","Value analog parameter",T_REAL,"10.2") );
+    elem->fldAdd( new TFld("OUT","Output of regulator",T_REAL,"10.2","","0;100") );
+    elem->fldAdd( new TFld("SP","Setpoint of regulator",T_REAL,"10.2") );
+    elem->fldAdd( new TFld("STAT","Stat regulator (Manual,Auto,Casc)",T_DEC|T_SELECT,"1","","0;1;2","Manual;Auto;Cascad") );
+    elem->fldAdd( new TFld("Kp","Koefficient of proportion",T_REAL,"6.2","","-20;20") );
+    elem->fldAdd( new TFld("Ti","Time of integrated (sek)",T_REAL,"7.2","","0;1000") );
+    elem->fldAdd( new TFld("Td","Time of diff (sek)",T_REAL,"7.2","","0;1000") );
+    elem->fldAdd( new TFld("Tf","Time of lag (sek)",T_REAL,"7.2","","0;1000") );
+    elem->fldAdd( new TFld("H_UP","Up out border (%)",T_REAL,"6.2","","0;100") );
+    elem->fldAdd( new TFld("H_DOWN","Down out border (%)",T_REAL,"6.2","","0;100") );
+    elem->fldAdd( new TFld("ZN","Non-sensitive pid error (%)",T_REAL,"5.2","","0;20") );
+    elem->fldAdd( new TFld("K1","Koefficient scale of addon input 1",T_REAL,"6.2","","-20;20") );
+    elem->fldAdd( new TFld("K2","Koefficient scale of addon input 2",T_REAL,"6.2","","-20;20") );
+    elem->fldAdd( new TFld("K3","Koefficient scale of addon input 3",T_REAL,"6.2","","-20;20") );
+    elem->fldAdd( new TFld("K4","Koefficient scale of addon input 4",T_REAL,"6.2","","-20;20") );
+    val_el.push_back(elem);    
     //Load algobloks
-    algbs = new TVirtAlgb(NameCfgF);
+    algbs = new TVirtAlgb(NameCfgF);  //Old
+    loadBD();  //NEW
 }
 
-TController *TVirtual::ContrAttach( const string &name, const SBDS &bd)
+TController *TVirtual::ContrAttach( const string &name, const TBDS::SName &bd)
 {
-    return( new TVContr(name,bd,this,this));    
+    return( new TVContr(name,bd,this,this));
 }
 
+void TVirtual::loadBD()
+{
+    int        buf_len = 100000;
+    dword      ofs_alg;
+    word       form_am, k_alg, len_2;
+    byte       len_1;
+    char       *buf;
+    
+    int fh = open(NameCfgF.c_str(),O_RDONLY);
+    if(fh == -1) throw TError("%s: Open file %s for read, error!",MOD_ID,NameCfgF.c_str());    
+
+    buf = (char *)malloc(buf_len);
+    
+    read(fh,&ofs_alg,4); 
+    read(fh,&form_am,2);
+    for(unsigned i_frm = 0; i_frm < form_am; i_frm++)
+    {
+	string     s_buf;
+        byte       tp,n_inp,n_koef;
+	
+	XMLNode frm("frm");
+       	frm.attr("id","std_"+SYS->int2str(i_frm));
+       	read(fh,&len_1,1);
+	if(len_1)
+	{
+	    read(fh,buf,len_1); buf[len_1] = '\0';
+	    frm.text(Mess->SconvIn("CP866",buf));
+	}       
+	read(fh,&tp,1);
+	read(fh,&n_inp,1); 
+	read(fh,&n_koef,1);
+	
+	if(n_inp)
+   	    for(unsigned i_inp=0;i_inp < n_inp;i_inp++)
+   	    {
+		XMLNode *io = frm.childAdd("io");
+       		read(fh,&len_1,1);
+		read(fh,buf,len_1);
+		s_buf.assign(buf,len_1);
+	       	io->attr("id","io_"+SYS->int2str(i_inp));
+	       	io->text(s_buf);
+	    }
+	if(n_koef)
+	    for(unsigned i_kf=0;i_kf < n_koef;i_kf++)
+	    {
+		XMLNode *io = frm.childAdd("kf");
+		read(fh,&len_1,1);
+		read(fh,buf,len_1);
+		s_buf.assign(buf,len_1);
+	       	io->attr("id","io_"+SYS->int2str(i_kf));
+	       	io->text(s_buf);		
+	    }
+	read(fh,&len_2,2);
+    	read(fh,buf,len_2); buf[len_2] = '\0';
+	if(tp != 5 ) s_buf = buf;
+	else         s_buf = "In progress!!!";
+	frm.childAdd("formula")->text(Mess->SconvIn("CP866",s_buf));
+	
+        frm_add(frm.attr("id"), &frm );
+    }
+    /*
+    lseek(fh,ofs_alg,SEEK_SET);
+    read(fh,&k_alg,2);
+    for(unsigned i_alg=0; i_alg < k_alg; i_alg++)
+    {
+        byte    n_inp,n_koef;
+	string  s_buf;
+	XMLNode alg("alg");
+	
+    	read(fh,buf,9); buf[9] = 0;
+	for(int i=8; i >= 0; i--) 
+	    if(buf[i]==' ' || buf[i]== 0) buf[i]=0; 
+	    else break; 
+	s_buf = buf;
+	Mess->SconvIn("CP866",s_buf);
+       	alg.attr("id",s_buf);
+
+	read(fh,&len_1,1); 
+	read(fh,buf,len_1);
+	s_buf.assign(buf,len_1);	
+	Mess->SconvIn("CP866",s_buf);
+       	alg.text(s_buf);
+	
+	read(fh,&len_2,2);
+	string form_n = string("std_")+SYS->int2str(len_2);
+	alg->childAdd("formula")->attr("id",form_n);
+	for( int i_frm = 0; i_frm < m_frm.size(); i_frm++ )
+	    if( m_frm[i_frm].name() == form_n )
+		//????????????
+	
+	unsigned i_n = frm_s[tp_alg]->n_inp;
+	if(i_n)
+	    for(unsigned i_x=0;i_x < i_n;i_x++)
+	    { 
+		if( i_x == algb->io.size() ) algb->io.push_back("");
+		
+		read(fh,buf,9); buf[9] = 0;
+		for(int i=8; i >= 0; i--) 
+		    if(buf[i]==' ' || buf[i]== 0) buf[i]=0; 
+		    else break;
+		algb->io[i_x] = buf;
+		Mess->SconvIn("CP866",algb->io[i_x]);
+	    }
+	i_n = frm_s[tp_alg]->n_koef;
+	if(i_n)
+	    for(unsigned i_k = 0;i_k < i_n; i_k++)
+	    {
+		if( i_k == algb->kf.size() ) algb->kf.push_back(0.0);
+		read(fh,&(algb->kf[i_k]),4);
+	    }
+	algb_s.push_back(algb);
+    }
+    */
+    free(buf);
+    close(fh); 
+}
+
+void TVirtual::saveBD()
+{
+
+}
+    	
+void TVirtual::frm_add( const string &name, XMLNode *dt )
+{
+    if( m_frm.objAvoid(name) ) return;
+    TFrm *frm = new TFrm(name,*this,dt);
+    try{ m_frm.objAdd( frm, &frm->name() ); }
+    catch(...) { delete frm; throw; }		
+}
+    	
+void TVirtual::alg_add( const string &name, XMLNode *dt )
+{
+    if( m_alg.objAvoid(name) ) return;
+    TAlg *alg = new TAlg(name,*this,dt);
+    try{ m_alg.objAdd( alg, &alg->name() ); }
+    catch(...) { delete alg; throw; }
+}
+
+//================== Controll functions ========================
+void TVirtual::ctrStat_( XMLNode *inf )
+{
+    char *dscr="dscr";
+    
+    TTipController::ctrStat_( inf );
+    
+    char *i_cntr =
+	"<area id='virt'>"
+    	" <area id='opt' acs='0440'>"
+	"  <fld id='a_cfg' acs='0660' tp='str'/>"
+	"  <fld id='f_cfg' acs='0660' tp='str'/>"
+	" </area>"					
+    	" <area id='alg' acs='0440'>"
+	"  <list id='alg' s_com='add,del' tp='br' mode='att'/>"
+	" </area>"					
+    	" <area id='frm' acs='0440'>"
+	"  <list id='frm' s_com='add,del' tp='br' mode='att'/>"
+	" </area>"					
+	"</area>";    
+
+    XMLNode *n_add = inf->childIns(1);    
+    n_add->load(i_cntr);
+    n_add->attr(dscr,I18N(MOD_NAME));
+    XMLNode *c_xml = n_add->childGet(0);
+    c_xml->attr(dscr,I18N("Config"));
+    c_xml->childGet(0)->attr(dscr,I18N("Algoblok's config file"));
+    c_xml->childGet(1)->attr(dscr,I18N("Formul's config file"));
+    c_xml = n_add->childGet(1);
+    c_xml->attr(dscr,I18N("Algobloks"));
+    c_xml->childGet(0)->attr(dscr,I18N("Algobloks"));
+    c_xml = n_add->childGet(2);
+    c_xml->attr(dscr,I18N("Formuls"));
+    c_xml->childGet(0)->attr(dscr,I18N("Formuls"));
+    
+    //Insert to Help
+    char *i_help = "<fld id='g_help' acs='0440' tp='str' cols='90' rows='5'/>";
+    
+    n_add = inf->childGet("id","help")->childAdd();    
+    n_add->load(i_help);
+    n_add->attr(dscr,Mess->I18N("Options help"));
+}
+
+void TVirtual::ctrDinGet_( const string &a_path, XMLNode *opt )
+{
+    vector<string> list;
+    
+    if( a_path == "/virt/opt/a_cfg" )		ctrSetS( opt, algbCfg );
+    else if( a_path == "/virt/opt/f_cfg" )	ctrSetS( opt, formCfg );
+    else if( a_path == "/virt/frm/frm" )
+    {
+	frm_list(list);
+	opt->childClean();
+	for( unsigned i_f=0; i_f < list.size(); i_f++ )
+	    ctrSetS( opt, list[i_f], i_f );
+    }
+    else if( a_path == "/virt/alg/alg" )
+    {
+	alg_list(list);
+	opt->childClean();
+	for( unsigned i_f=0; i_f < list.size(); i_f++ )
+	    ctrSetS( opt, list[i_f], i_f );
+    }
+    else if( a_path == "/help/g_help" ) 	ctrSetS( opt, optDescr() );
+    else TTipController::ctrDinGet_( a_path, opt );
+}
+
+void TVirtual::ctrDinSet_( const string &a_path, XMLNode *opt )
+{
+    if( a_path == "/virt/opt/a_cfg" )		algbCfg = ctrGetS( opt );
+    else if( a_path == "/virt/opt/f_cfg" )	formCfg = ctrGetS( opt );
+    else if( a_path.substr(0,13) == "/virt/frm/frm" )
+    {
+	for( int i_el=0; i_el < opt->childSize(); i_el++)
+	{
+	    XMLNode *t_c = opt->childGet(i_el);
+	    if( t_c->name() == "el")
+    	    {
+		if(t_c->attr("do") == "add")      frm_add(t_c->text());
+		else if(t_c->attr("do") == "del") frm_del(t_c->text());
+	    }
+	}	    
+    }
+    else if( a_path.substr(0,13) == "/virt/alg/alg" )
+    {
+	for( int i_el=0; i_el < opt->childSize(); i_el++)
+	{
+	    XMLNode *t_c = opt->childGet(i_el);
+	    if( t_c->name() == "el")
+    	    {
+		if(t_c->attr("do") == "add")      alg_add(t_c->text());
+		else if(t_c->attr("do") == "del") alg_del(t_c->text());
+	    }
+	}	    
+    }
+    else TTipController::ctrDinSet_( a_path, opt );
+}
+
+AutoHD<TContr> TVirtual::ctrAt1( const string &br )
+{
+    if( br.substr(0,13) == "/virt/frm/frm" )   		return frm_at(pathLev(br,3));
+    else if( br.substr(0,13) == "/virt/alg/alg" )	return alg_at(pathLev(br,3));
+    else return TTipController::ctrAt1(br);
+}
+
+//======================================================================
+//==== TAlg 
+//======================================================================
+TAlg::TAlg( const string &name, TVirtual &owner, XMLNode *dt ) : 
+    m_name(name), m_owner(owner)
+{ 
+    if( dt != NULL && dt->name() == "frm" )
+    {
+	m_lname = dt->text( );
+    }
+}
+
+TAlg::~TAlg()
+{ 
+
+}
+
+void TAlg::ctrStat_( XMLNode *inf )
+{
+    char *i_cntr =
+	"<oscada_cntr>"
+	"</oscada_cntr>";
+
+    inf->load( i_cntr );
+    inf->text( m_owner.I18Ns("Algoblok: ")+name() );
+}
+
+
+
+//======================================================================
+//==== TFrm 
+//======================================================================
+TFrm::TFrm( const string &name, TVirtual &owner, XMLNode *dt ) : 
+    m_name(name), m_owner(owner)
+{ 
+    if( dt != NULL && dt->name() == "frm" )
+    {
+	m_lname = dt->text( );	
+	form    = dt->childGet("formula")->text( );
+    }
+}
+
+TFrm::~TFrm()
+{ 
+
+}
+
+void TFrm::ctrStat_( XMLNode *inf )
+{
+    char *i_cntr =
+	"<oscada_cntr>"
+	" <area id='gen'>"
+	"  <fld id='nm' acs='0444' tp='str'/>"
+	"  <fld id='lnm' acs='0664' tp='str'/>"
+	"  <fld id='frm' acs='0664' tp='str' cols='100' rows='20'/>"
+	" </area>"	
+	"</oscada_cntr>";
+    char *dscr = "dscr";
+
+    inf->load( i_cntr );
+    inf->text( m_owner.I18Ns("Formula: ")+name() );
+    XMLNode *t_cntr = inf->childGet(0);
+    t_cntr->attr(dscr,m_owner.I18N("Formula control"));
+    t_cntr->childGet(0)->attr(dscr,Mess->I18N("Name"));
+    t_cntr->childGet(1)->attr(dscr,Mess->I18N("Description"));
+    t_cntr->childGet(2)->attr(dscr,Mess->I18N("Formula"));
+}
+
+void TFrm::ctrDinGet_( const string &a_path, XMLNode *opt )
+{
+    if( a_path == "/gen/nm" )		ctrSetS( opt, m_name );
+    else if( a_path == "/gen/lnm" )	ctrSetS( opt, m_lname );
+    else if( a_path == "/gen/frm" )	ctrSetS( opt, form );
+    else throw TError("(%s) Branch %s error",__func__,a_path.c_str());
+}
+
+void TFrm::ctrDinSet_( const string &a_path, XMLNode *opt )
+{
+    if( a_path == "/gen/lnm" )		m_lname = ctrGetS( opt );
+    else if( a_path == "/gen/frm" )	form    = ctrGetS( opt );
+    else throw TError("(%s) Branch %s error",__func__,a_path.c_str());
+}
+
+
 //======================================================================
 //==== TVContr 
 //======================================================================
 
-TVContr::TVContr(  string name_c, const SBDS &bd, ::TTipController *tcntr, ::TElem *cfgelem) :
+TVContr::TVContr(  string name_c, const TBDS::SName &bd, ::TTipController *tcntr, ::TElem *cfgelem) :
     ::TController(name_c, bd, tcntr, cfgelem), endrun(false),
     period(cfg("PERIOD").getI()), per_sync(cfg("PER_S").getI()), iterate(cfg("ITER").getI())    
 {
@@ -253,20 +578,20 @@ TVContr::TVContr(  string name_c, const SBDS &bd, ::TTipController *tcntr, ::TEl
 
 TVContr::~TVContr()
 {
-    if( run_st ) Stop();
+    if( run_st ) stop();
 }
 
-void TVContr::Load_( )
+void TVContr::load_( )
 {
 
 }
 
-void TVContr::Save_( )
+void TVContr::save_( )
 {
 
 }
 
-void TVContr::Start_( )
+void TVContr::start_( )
 {   
     pthread_attr_t      pthr_attr;
     struct sched_param  prior;
@@ -278,14 +603,10 @@ void TVContr::Start_( )
     	list(list_p);
 	for(unsigned i_prm=0; i_prm < list_p.size(); i_prm++)
 	{
-	    AutoHD<TParamContr> prm_c = at(list_p[i_prm],Name()+"_start");
-	    ((TVPrm &)prm_c.at()).Load();
-	    ((TVPrm &)prm_c.at()).Enable();
+	    AutoHD<TVPrm> prm_c = at(list_p[i_prm],name()+"_start");
+	    prm_c.at().load();
+	    prm_c.at().enable();
 	    p_hd.push_back(prm_c);	    
-	    //int hd = att(list_p[i_prm],Name()+"_start");
-	    //( (TVPrm &)at( hd ) ).Load();
-	    //( (TVPrm &)at( hd ) ).Enable();
-	    //p_hd.push_back(hd);
 	}
 	//------------------------------------    
 	pthread_attr_init(&pthr_attr);
@@ -295,35 +616,31 @@ void TVContr::Start_( )
 	    pthread_attr_setschedpolicy(&pthr_attr,SCHED_FIFO);
 	    pthread_attr_setschedparam(&pthr_attr,&prior);
 	    
-	    Owner().m_put("SYS",MESS_DEBUG,"%s:Start into realtime mode!",Name().c_str());
+	    owner().mPut("SYS",MESS_DEBUG,"%s:Start into realtime mode!",name().c_str());
 	}
 	else pthread_attr_setschedpolicy(&pthr_attr,SCHED_OTHER);
 	pthread_create(&pthr_tsk,&pthr_attr,Task,this);
 	pthread_attr_destroy(&pthr_attr);
-	if( SYS->event_wait( run_st, true, string(NAME_MODUL)+": Controller "+Name()+" is starting....",5) )
-	    throw TError("%s: Controller %s no started!",NAME_MODUL,Name().c_str());    	    
+	if( SYS->event_wait( run_st, true, string(MOD_ID)+": Controller "+name()+" is starting....",5) )
+	    throw TError("%s: Controller %s no started!",MOD_ID,name().c_str());    	    
     }	
 }
 
-void TVContr::Stop_( )
+void TVContr::stop_( )
 {  
     if( run_st )
     {
 	endrun = true;
 	pthread_kill(pthr_tsk, SIGALRM);
-    	if( SYS->event_wait( run_st, false, string(NAME_MODUL)+": Controller "+Name()+" is stoping....",5) )
-    	    throw TError("%s: Controller %s no stoped!",NAME_MODUL,Name().c_str());
+    	if( SYS->event_wait( run_st, false, string(MOD_ID)+": Controller "+name()+" is stoping....",5) )
+    	    throw TError("%s: Controller %s no stoped!",MOD_ID,name().c_str());
 	pthread_join(pthr_tsk, NULL);
 	
 	for(unsigned i_prm=0; i_prm < p_hd.size(); i_prm++)
-	    ((TVPrm &)p_hd[i_prm].at()).Disable();
+	    ((TVPrm &)p_hd[i_prm].at()).disable();
 	p_hd.clear();
 	for(unsigned i_prm=0; i_prm < p_io_hd.size(); i_prm++)
-	{
-	    if( p_io_hd[i_prm]->internal ) det( p_io_hd[i_prm]->hd_prm );
-	    else Owner().Owner().Owner().Param().det( p_io_hd[i_prm]->hd_prm );
 	    delete p_io_hd[i_prm];
-	}
 	p_io_hd.clear();    
     }
 } 
@@ -338,7 +655,7 @@ void *TVContr::Task(void *contr)
     TVContr *cntr = (TVContr *)contr;
 
 #if OSC_DEBUG
-    cntr->Owner().m_put("DEBUG",MESS_DEBUG,"%s: Thread <%d>!",cntr->Name().c_str(),getpid() );
+    cntr->owner().mPut("DEBUG",MESS_DEBUG,"%s: Thread <%d>!",cntr->name().c_str(),getpid() );
 #endif	
 
     try
@@ -371,7 +688,7 @@ void *TVContr::Task(void *contr)
 	    if( time_t2 != (time_t1+cntr->period*frq/1000) )
 	    {
 		cnt_lost+=time_t2-(time_t1+cntr->period*frq/1000);
-		cntr->Owner().m_put("DEBUG",MESS_DEBUG,"%s:Lost ticks %d - %d (%d)",cntr->Name().c_str(),time_t2,time_t1+cntr->period*frq/1000,cnt_lost);
+		cntr->owner().mPut("DEBUG",MESS_DEBUG,"%s:Lost ticks %d - %d (%d)",cntr->name().c_str(),time_t2,time_t1+cntr->period*frq/1000,cnt_lost);
 	    }
 	    time_t1 = time_t2;	
 	    //----------------
@@ -383,7 +700,7 @@ void *TVContr::Task(void *contr)
 		    ((TVPrm &)cntr->p_hd[i_p].at()).Calc();
 	}
     } catch(TError err) 
-    { cntr->Owner().m_put("SYS",MESS_ERR,"%s: Error: %s!",cntr->Name().c_str(),err.what().c_str() ); }    
+    { cntr->owner().mPut("SYS",MESS_ERR,"%s: Error: %s!",cntr->name().c_str(),err.what().c_str() ); }    
     
     cntr->run_st = false;
     
@@ -392,14 +709,14 @@ void *TVContr::Task(void *contr)
 
 void TVContr::Sync()
 {
-    TKernel &Kern = Owner().Owner().Owner();
+    TKernel &Kern = owner().owner().owner();
     for(unsigned i_x = 0; i_x < p_io_hd.size(); i_x++)
 	if( !p_io_hd[i_x]->internal )
 	{
 	    try
 	    {
 		string vl_nm = "VAL";
-		AutoHD<TVal> val = Kern.Param()[p_io_hd[i_x]->hd_prm].at().vlAt(vl_nm);
+		AutoHD<TVal> val = p_io_hd[i_x]->hd_g.at().at().vlAt(vl_nm);
 		if( !val.at().valid() ) continue;
 		if( p_io_hd[i_x]->sync )
 		{
@@ -416,45 +733,45 @@ void TVContr::Sync()
 
 TParamContr *TVContr::ParamAttach( const string &name, int type )
 {
-    return(new TVPrm(name,&Owner().at_TpPrm(type),this));
+    return(new TVPrm(name,&owner().tpPrmAt(type),this));
 }
 
-int TVContr::prm_connect( string name )
+int TVContr::prm_connect( string nm )
 {
     STime tm = {0,0}; 
     //Find already connected
     for(unsigned i_hd = 0; i_hd < p_io_hd.size(); i_hd++)
     {
-	if( p_io_hd[i_hd]->internal && at(p_io_hd[i_hd]->hd_prm).Name() == name )	
+	if( p_io_hd[i_hd]->internal && p_io_hd[i_hd]->hd_i.at().name() == nm )	
 	    return(i_hd);
-	if( !p_io_hd[i_hd]->internal && Owner().Owner().Owner().Param().at(p_io_hd[i_hd]->hd_prm).Name() == name )	
+	if( !p_io_hd[i_hd]->internal && p_io_hd[i_hd]->hd_g.at().name() == nm )	
 	    return(i_hd);
     }
     //Create new
-    SIO io;
+    SIO *io = new SIO;
     try
     {
-	io.hd_prm   = att(name,Name());
-	io.internal = true;
+	io->hd_i	= at(nm,name());
+	io->internal	= true;
     }
     catch(...)
     {   
 	try
 	{
-	    io.hd_prm   = Owner().Owner().Owner().Param().att(name,Name());
-    	    io.internal = false;
+	    io->hd_g 	= owner().owner().owner().Param().at(nm,name());
+    	    io->internal= false;
 	}
 	catch(...) { return(-1); }
     }
-    io.x = 0.0;
-    p_io_hd.push_back( new SIO(io) );
+    io->x = 0.0;
+    p_io_hd.push_back( io );
     
     return( p_io_hd.size()-1 );
 }
 
 SIO &TVContr::prm( unsigned hd )
 {
-    if(hd >= p_io_hd.size()) throw TError("%s: hd %d no avoid!",NAME_MODUL,hd);
+    if(hd >= p_io_hd.size()) throw TError("%s: hd %d no avoid!",MOD_ID,hd);
     return( *p_io_hd[hd] );
 }
 
@@ -500,20 +817,20 @@ TVPrm::~TVPrm( )
 
 void TVPrm::vlSet( int id_elem )
 {
-    Owner().Owner().m_put("DEBUG",MESS_WARNING,"%s:%s:Comand to direct set value of element!",Owner().Name().c_str(),Name().c_str());
+    owner().owner().mPut("DEBUG",MESS_WARNING,"%s:%s:Comand to direct set value of element!",owner().name().c_str(),name().c_str());
 }
 
 void TVPrm::vlGet( int id_elem )
 {
-    Owner().Owner().m_put("DEBUG",MESS_WARNING,"%s: Comand to direct get value of element!",Owner().Name().c_str(),Name().c_str());
+    owner().owner().mPut("DEBUG",MESS_WARNING,"%s: Comand to direct get value of element!",owner().name().c_str(),name().c_str());
 }
 
-void TVPrm::Load( )
+void TVPrm::load( )
 {
     SAlgb *algb = NULL;
     try
     {
-	algb = ( (TVirtual &)( (TVContr &)Owner() ).Owner() ).AlgbS()->GetAlg(Name());
+	algb = ( (TVirtual &)( (TVContr &)owner() ).owner() ).AlgbS()->GetAlg(name());
     }
     catch(TError err) 
     {
@@ -522,11 +839,11 @@ void TVPrm::Load( )
     }
     form = algb->tp_alg;
     
-    y_id = ( (TVContr &)Owner() ).prm_connect(Name());
+    y_id = ( (TVContr &)owner() ).prm_connect(name());
     for(unsigned i_x=0; i_x < algb->io.size(); i_x++)
     {
 	if( i_x >= x_id.size() ) x_id.insert(x_id.begin()+i_x,-1);
-	x_id[i_x] =  ( (TVContr &)Owner() ).prm_connect(algb->io[i_x]);
+	x_id[i_x] =  ( (TVContr &)owner() ).prm_connect(algb->io[i_x]);
     }
     for(unsigned i_k = 0;i_k < algb->kf.size(); i_k++)
     {
@@ -539,7 +856,7 @@ inline void TVPrm::Y(float val)
 {
     float val_t;
     
-    SIO &io = ( (TVContr &)Owner() ).prm(y_id);   
+    SIO &io = ( (TVContr &)owner() ).prm(y_id);   
     val_t = val;
     if(io.x != val_t) { io.sync = true; io.x = val_t; }
     /*
@@ -550,7 +867,7 @@ inline void TVPrm::Y(float val)
 
 inline float TVPrm::Y()
 { 
-    return( ( (TVContr &)Owner() ).prm(y_id).x );
+    return( ( (TVContr &)owner() ).prm(y_id).x );
     /*
     STime tm = {0,0};
     return(_vl_GetR(hd_y,tm));
@@ -562,7 +879,7 @@ inline void TVPrm::X(unsigned id ,float val)
     float val_t;
 
     if(x_id[id] < 0) return;
-    SIO &io = ( (TVContr &)Owner() ).prm(x_id[id]);   
+    SIO &io = ( (TVContr &)owner() ).prm(x_id[id]);   
     val_t = val;
     if(io.x != val_t) { io.sync = true; io.x = val_t; }
 }
@@ -570,7 +887,7 @@ inline void TVPrm::X(unsigned id ,float val)
 inline float TVPrm::X(unsigned id)
 {
     if(x_id[id] < 0) return(0.0);
-    return( ( (TVContr &)Owner() ).prm(x_id[id]).x );
+    return( ( (TVContr &)owner() ).prm(x_id[id]).x );
 }
 
 void TVPrm::Sync()
@@ -583,7 +900,7 @@ float TVPrm::Calc()
     if(form < 0) return(1E+10);
 
     
-    switch( ((TVirtual &)((TVContr &)Owner()).Owner()).AlgbS()->GetFrm(form)->tip)
+    switch( ((TVirtual &)((TVContr &)owner()).owner()).AlgbS()->GetFrm(form)->tip)
     {	
 	case  0:return(0.0);
 	case  1:return blok_dig();
@@ -619,9 +936,9 @@ float TVPrm::Calc()
 //      case 33:return alarmk(GB);
 //      case 34:return srob(GB);
     }
-    Owner().Owner().m_put("CONTR",MESS_WARNING,"%s:%s:%d Furmule id= %d no avoid!",
-		Owner().Name().c_str(),Name().c_str(),form, 
-		((TVirtual &)((TVContr &)Owner()).Owner()).AlgbS()->GetFrm(form)->tip);
+    owner().owner().mPut("CONTR",MESS_WARNING,"%s:%s:%d Furmule id= %d no avoid!",
+		owner().name().c_str(),name().c_str(),form, 
+		((TVirtual &)((TVContr &)owner()).owner()).AlgbS()->GetFrm(form)->tip);
 
     return(1E+10);
 }
@@ -638,7 +955,7 @@ float TVPrm::blok_dig( )
     if(X(2) && k[2] != 2.) { k[2]=2.; set = true; }
     if(X(4) && k[2] != 3.) { k[2]=3.; set = true; }
     if( set && k[0] > 0. ) { k[1]=k[0]; set = false; }
-    if(k[1] > 0.) k[1] -= ((TVContr &)Owner()).Period()/(1000*sysconf(_SC_CLK_TCK)*((TVContr &)Owner()).Iterate());
+    if(k[1] > 0.) k[1] -= ((TVContr &)owner()).Period()/(1000*sysconf(_SC_CLK_TCK)*((TVContr &)owner()).Iterate());
     else
     {
     	k[1] = 0.;
@@ -679,7 +996,7 @@ float TVPrm::sym()
 float TVPrm::free_formul( )
 {
     int offset = 0;
-    SFrm *formul = ((TVirtual &)((TVContr &)Owner()).Owner()).AlgbS()->GetFrm(form);
+    SFrm *formul = ((TVirtual &)((TVContr &)owner()).owner()).AlgbS()->GetFrm(form);
     return(calk_form(formul->form_e,formul->l_frm_e,&offset,0,0));
 }
                
@@ -693,7 +1010,6 @@ float TVPrm::calk_form(char *form, int len, int *off, float rez,byte h_prior)
     byte    flow_prior=0;
     byte    tmb_b;
 
-
     hom_f:
     if(*off > len-1) goto exit_f;
     b_form = form[*off];
@@ -771,8 +1087,8 @@ float TVPrm::calk_form(char *form, int len, int *off, float rez,byte h_prior)
     if((oper&0x00FFFFFF) == 'qrf')                 //frq
     {
 	(*off)+=3;
-	if(symb) parm = 1000*((TVContr &)Owner()).Iterate()*sysconf(_SC_CLK_TCK)/((TVContr &)Owner()).Period();
-	else     rez  = 1000*((TVContr &)Owner()).Iterate()*sysconf(_SC_CLK_TCK)/((TVContr &)Owner()).Period();
+	if(symb) parm = 1000*((TVContr &)owner()).Iterate()*sysconf(_SC_CLK_TCK)/((TVContr &)owner()).Period();
+	else     rez  = 1000*((TVContr &)owner()).Iterate()*sysconf(_SC_CLK_TCK)/((TVContr &)owner()).Period();
 	goto hom_f;
     }
     if(oper == *(dword *)"exp(")                             //exp()
@@ -941,9 +1257,9 @@ float TVPrm::pid_n( )
     if(!pid) return(1E+10);
     
     
-    int    period      = ((TVContr &)Owner()).Period();
+    int    period      = ((TVContr &)owner()).Period();
     int    HZ          = 1000*sysconf(_SC_CLK_TCK);
-    int    cnt_in_cycl = ((TVContr &)Owner()).Iterate();
+    int    cnt_in_cycl = ((TVContr &)owner()).Iterate();
     float  sp          = pid->sp->getR();
     float  out         = pid->out->getR();
     char   stat        = pid->stat->getI();
@@ -1028,7 +1344,7 @@ float TVPrm::pid_n( )
 
 TVirtAlgb::TVirtAlgb(string cfg_file) : file(cfg_file)
 {
-    Load();
+    load();
 }
 
 TVirtAlgb::~TVirtAlgb( )
@@ -1036,7 +1352,7 @@ TVirtAlgb::~TVirtAlgb( )
     Free();
 }
 
-void TVirtAlgb::Load(string f_alg)
+void TVirtAlgb::load(string f_alg)
 {
     int        buf_len = 100000;
     dword      ofs_alg;
@@ -1046,10 +1362,10 @@ void TVirtAlgb::Load(string f_alg)
     
     if(f_alg.size())     file_alg = (char *)f_alg.c_str();
     else if(file.size()) file_alg = (char *)file.c_str();
-    else throw TError("%s: File algoblocs no avoid!",NAME_MODUL);
+    else throw TError("%s: File algoblocs no avoid!",MOD_ID);
    
     int fh = open(file_alg,O_RDONLY);
-    if(fh == -1) throw TError("%s: Open file %s for read, error!",NAME_MODUL,file_alg);    
+    if(fh == -1) throw TError("%s: Open file %s for read, error!",MOD_ID,file_alg);    
 
     Free();
 
@@ -1064,8 +1380,7 @@ void TVirtAlgb::Load(string f_alg)
 	if(len_1)
 	{
 	    read(fh,buf,len_1); buf[len_1]=0;
-	    frm->name = buf;
-	    Mess->SconvIn("CP866",frm->name);
+	    frm->name = Mess->SconvIn("CP866",buf);
 	}
        
 	read(fh,&frm->tip,1);
@@ -1157,13 +1472,11 @@ void TVirtAlgb::Load(string f_alg)
 	for(int i=8; i >= 0; i--) 
 	    if(buf[i]==' ' || buf[i]== 0) buf[i]=0; 
 	    else break; 
-	algb->name = buf;
-	Mess->SconvIn("CP866",algb->name);
+	algb->name = Mess->SconvIn("CP866",buf);
 
 	read(fh,&len_1,1); 
 	read(fh,buf,len_1); buf[len_1]=0;
-	algb->descr = buf;
-	Mess->SconvIn("CP866",algb->descr);
+	algb->descr = Mess->SconvIn("CP866",buf);
 	
 	read(fh,&tp_alg,2);
 	algb->tp_alg = tp_alg;
@@ -1178,8 +1491,7 @@ void TVirtAlgb::Load(string f_alg)
 		for(int i=8; i >= 0; i--) 
 		    if(buf[i]==' ' || buf[i]== 0) buf[i]=0; 
 		    else break;
-		algb->io[i_x] = buf;
-		Mess->SconvIn("CP866",algb->io[i_x]);
+		algb->io[i_x] = Mess->SconvIn("CP866",buf);
 	    }
 	i_n = frm_s[tp_alg]->n_koef;
 	if(i_n)
@@ -1194,16 +1506,16 @@ void TVirtAlgb::Load(string f_alg)
     close(fh); 
 }
 
-void TVirtAlgb::Save(string f_alg)
+void TVirtAlgb::save(string f_alg)
 {
     char   *file_alg;
     
     if(f_alg.size())     file_alg = (char *)f_alg.c_str();
     else if(file.size()) file_alg = (char *)file.c_str();
-    else throw TError("%s: File algobloks no avoid!",NAME_MODUL);
+    else throw TError("%s: File algobloks no avoid!",MOD_ID);
    
     int fh = open(file_alg,O_WRONLY);
-    if(fh == -1) throw TError("%s: Open file %s for write, error!",NAME_MODUL,file_alg);    
+    if(fh == -1) throw TError("%s: Open file %s for write, error!",MOD_ID,file_alg);    
     //----------------
     //make in future
     //----------------    
@@ -1230,12 +1542,12 @@ SAlgb *TVirtAlgb::GetAlg(string name)
 {
     for(unsigned i_alg = 0; i_alg < algb_s.size(); i_alg++)
 	if(algb_s[i_alg]->name == name) return(algb_s[i_alg]);
-    throw TError("%s: Algoblok %s no avoid!",NAME_MODUL,name.c_str());
+    throw TError("%s: Algoblok %s no avoid!",MOD_ID,name.c_str());
 }
 
 SFrm *TVirtAlgb::GetFrm(unsigned id)
 {
     if( id < frm_s.size() ) return( frm_s[id] );
-    throw TError("%s: Formule %d no avoid!",NAME_MODUL,id);
+    throw TError("%s: Formula %d no avoid!",MOD_ID,id);
 }
 
