@@ -33,7 +33,7 @@
 #include "tkernel.h"
 #include "tmessage.h"
 #include "tbds.h"
-#include "tarhives.h"
+#include "tarchives.h"
 #include "tparams.h"
 #include "tparam.h"
 #include "tcontroller.h"
@@ -48,23 +48,14 @@
 
 const char *TModSchedul::o_name = "TModSchedul";
 const char *TModSchedul::s_name = "Modules sheduler";
-const char *TModSchedul::i_cntr = 
-	"<oscada_cntr>"
-	" <area id='a_ms' dscr='Subsystem control.' acs='0440'>"
-	"  <fld id='mod_path' com='1' cfg='1' dest='dir' tp='str'/>"
-	"  <list id='mod_auto' tp='str' dest='file'/>"
-	"  <fld id='g_help' acs='0440' tp='str' cols='90' rows='5'/>"
-	" </area>"
-	"</oscada_cntr>";
 
-TModSchedul::TModSchedul( TKernel *app ) : m_stat(false), owner(app), m_mod_path("./")
+TModSchedul::TModSchedul( TKernel *app ) : m_stat(false), m_owner(app), m_mod_path("./")
 {
-    hd_res = ResAlloc::ResCreate();
+    hd_res = ResAlloc::resCreate();
 }
 
 TModSchedul::~TModSchedul(  )
 {
-    DeinitAll();
     if( m_stat ) 
     {
     	m_endrun = true;
@@ -76,28 +67,28 @@ TModSchedul::~TModSchedul(  )
     ResAlloc res(hd_res,true);
     for( unsigned i_sh = 0; i_sh < SchHD.size(); i_sh++ )
 	if( SchHD[i_sh]->hd )
-	{
-    	    while( SchHD[i_sh]->use.size() )
+	{        
+	    while( SchHD[i_sh]->use.size() )
 	    {	
-		string n_mod = grpmod[SchHD[i_sh]->use[0].id_tmod]->gmd_at( SchHD[i_sh]->use[0].id_mod ).mod_Name();
-	       	grpmod[SchHD[i_sh]->use[0].id_tmod]->gmd_det( SchHD[i_sh]->use[0].id_mod );
-	       	grpmod[SchHD[i_sh]->use[0].id_tmod]->gmd_del( n_mod );
+		string n_mod = SchHD[i_sh]->use[0].mod.at().modName();
+		SchHD[i_sh]->use[0].mod.free();
+	       	grpmod[SchHD[i_sh]->use[0].id_tmod]->gmdDel( n_mod );
 		SchHD[i_sh]->use.erase(SchHD[i_sh]->use.begin());
-	    }
+	    }	    
 	    dlclose(SchHD[i_sh]->hd);
 	    SchHD[i_sh]->hd = NULL;
 	}	
     res.release();
     
-    ResAlloc::ResDelete(hd_res);
+    ResAlloc::resDelete(hd_res);
 }
 
-string TModSchedul::Name()
+string TModSchedul::name()
 { 
     return(Mess->I18N((char *)s_name)); 
 }
 
-string TModSchedul::opt_descr( )
+string TModSchedul::optDescr( )
 {
     char buf[STR_BUF_LEN];
     snprintf(buf,sizeof(buf),Mess->I18N(
@@ -105,13 +96,13 @@ string TModSchedul::opt_descr( )
     	"    --ModPath=<path>   set modules <path>: \"/var/os/modules/,./mod/\"\n"
 	"------------ Parameters of section <%s> in config file -----------\n"
     	"mod_path  <path>       set path to shared libs;\n"
-    	"mod_auto  <list>       names of automatic loaded, attached and started shared libs <direct_dbf.so;virt.so>\n"
+    	"mod_auto  <list>       names of automatic loaded, attached and started shared libs <direct_dbf.so;virt.so>\n\n"
 	),s_name);
     
     return(buf);
 }
 
-void TModSchedul::StartSched( )
+void TModSchedul::schedStart( )
 { 
     if( m_stat ) return;
     pthread_attr_t      pthr_attr;
@@ -135,10 +126,8 @@ void *TModSchedul::SchedTask(void *param)
     shed->m_endrun = false;
     
 #if OSC_DEBUG
-    shed->Owner().m_put("DEBUG",MESS_DEBUG,"%s:Thread <%d>!",s_name,getpid() );
+    shed->owner().mPut("DEBUG",MESS_DEBUG,"%s:Thread <%d>!",s_name,getpid() );
 #endif
-//    setenv("_","OpenScada: test",1);
-//    Owner().SetTaskTitle("TEST");
     do 
     {	
 	try
@@ -147,11 +136,11 @@ void *TModSchedul::SchedTask(void *param)
 	    {
 		cntr = 0;
 		
-		shed->Load(shed->m_mod_path,-1,true);
+		shed->libLoad(shed->m_mod_path,-1,true);
 		for(unsigned i_gm=0; i_gm < shed->grpmod.size(); i_gm++)
-		    shed->Load(shed->grpmod[i_gm]->gmd_ModPath(),i_gm,true);
+		    shed->libLoad(shed->grpmod[i_gm]->gmdModPath(),i_gm,true);
 	    }
-	} catch(TError err){ shed->Owner().m_put("SYS",MESS_ERR,"%s:%s",s_name,err.what().c_str()); }
+	} catch(TError err){ shed->owner().mPut("SYS",MESS_ERR,"%s:%s",s_name,err.what().c_str()); }
 	usleep(STD_WAIT_DELAY*1000);
     } while( !shed->m_endrun );
     shed->m_stat   = false;
@@ -159,7 +148,7 @@ void *TModSchedul::SchedTask(void *param)
     return(NULL);
 }
 
-int TModSchedul::RegGroupM(TGRPModule *gmod)
+int TModSchedul::gmdReg(TGRPModule *gmod)
 {
     if(gmod == NULL) return(-1);
     for(unsigned i_grmd = 0; i_grmd < grpmod.size(); i_grmd++)
@@ -169,7 +158,7 @@ int TModSchedul::RegGroupM(TGRPModule *gmod)
     return(grpmod.size()-1);
 }
 
-int TModSchedul::UnRegGroupM(TGRPModule *gmod)
+int TModSchedul::gmdUnReg(TGRPModule *gmod)
 {
     if(gmod == NULL) return(-1);
     for(unsigned i_grmd = 0; i_grmd < grpmod.size(); i_grmd++)
@@ -182,26 +171,27 @@ int TModSchedul::UnRegGroupM(TGRPModule *gmod)
     return(-2);
 }
 
-XMLNode *TModSchedul::XMLCfgNode()
+XMLNode *TModSchedul::cfgNode()
 {
     int i_k = 0;
     while(true)
     {
-	XMLNode *t_n = Owner().XMLCfgNode()->get_child("section",i_k++);
-	if( t_n->get_attr("id") == s_name ) return( t_n );
+	XMLNode *t_n = owner().cfgNode()->childGet("section",i_k++);
+	if( t_n->attr("id") == s_name ) return( t_n );
     }
 }
 
-void TModSchedul::CheckCommandLine(  )
+void TModSchedul::checkCommandLine(  )
 {
 #if OSC_DEBUG
-    Owner().m_put("DEBUG",MESS_INFO,"%s:Read commandline options!",s_name);
+    owner().mPut("DEBUG",MESS_INFO,"%s:Read commandline options!",s_name);
 #endif
 	
     int next_opt;
     char *short_opt="h";
     struct option long_opt[] =
     {
+	{"help"     ,0,NULL,'h'},
 	{"ModPath"  ,1,NULL,'m'},
 	{NULL       ,0,NULL,0  }
     };
@@ -212,35 +202,35 @@ void TModSchedul::CheckCommandLine(  )
 	next_opt=getopt_long(SYS->argc,( char *const * ) SYS->argv,short_opt,long_opt,NULL);
 	switch(next_opt)
 	{
-	    case 'h': fprintf(stdout,opt_descr().c_str()); break;
+	    case 'h': fprintf(stdout,optDescr().c_str()); break;
 	    case 'm': m_mod_path = optarg; break;
 	    case -1 : break;
 	}
     } while(next_opt != -1);
     
 #if OSC_DEBUG
-    Owner().m_put("DEBUG",MESS_DEBUG,"%s:Read commandline options ok!",s_name);
+    owner().mPut("DEBUG",MESS_DEBUG,"%s:Read commandline options ok!",s_name);
 #endif
 
     // Check all subsystems
     for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
-	grpmod[i_gm]->gmd_CheckCommandLine( );
+	grpmod[i_gm]->gmdCheckCommandLine( );
 }
 
-void TModSchedul::CheckCommandLineMod(  )
+void TModSchedul::checkCommandLineMod(  )
 {
     for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
-	grpmod[i_gm]->gmd_CheckCommandLineMods();
+	grpmod[i_gm]->gmdCheckCommandLineMods();
 }
 
-void TModSchedul::UpdateOpt()
+void TModSchedul::updateOpt()
 {
-    try{ m_mod_path = XMLCfgNode()->get_child("id","mod_path")->get_text(); }
+    try{ m_mod_path = cfgNode()->childGet("id","mod_path")->text(); }
     catch(...) {  }
     
     try
     {
-	string opt = XMLCfgNode()->get_child("id","mod_auto")->get_text();
+	string opt = cfgNode()->childGet("id","mod_auto")->text();
 	if( opt.size() )
 	{
 	    int i_beg = -1;
@@ -255,39 +245,33 @@ void TModSchedul::UpdateOpt()
     catch(...) {  }
     
     for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
-	grpmod[i_gm]->gmd_UpdateOpt();
+	grpmod[i_gm]->gmdUpdateOpt();
 }
 
-void TModSchedul::UpdateOptMod()
+void TModSchedul::updateOptMod()
 {
     for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
-	grpmod[i_gm]->gmd_UpdateOptMods();
+	grpmod[i_gm]->gmdUpdateOptMods();
 }
 
-void TModSchedul::LoadAll(  )
+void TModSchedul::gmdLoadAll(  )
 {
-    Load(m_mod_path,-1,false);
+    libLoad(m_mod_path,-1,false);
     for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
-	Load(grpmod[i_gm]->gmd_ModPath(),i_gm,false);
+	libLoad(grpmod[i_gm]->gmdModPath(),i_gm,false);
 }
 
-void TModSchedul::InitAll(  )
+void TModSchedul::gmdInitAll(  )
 {
     for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
-	grpmod[i_gm]->gmd_Init( );
+	grpmod[i_gm]->gmdInit( );
 }
 
-void TModSchedul::DeinitAll(  )
-{
-//  for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
-//	grpmod[i_gm]->gmd_Deinit( );
-}
-
-void TModSchedul::StartAll(  )
+void TModSchedul::gmdStartAll(  )
 {
     for(unsigned i_gm=0; i_gm < grpmod.size(); i_gm++)
     {
-	try{ grpmod[i_gm]->gmd_Start( ); }
+	try{ grpmod[i_gm]->gmdStart( ); }
 	catch(...){ }
     }
 }
@@ -309,7 +293,7 @@ void TModSchedul::ScanDir( const string &Paths, vector<string> &files, bool new_
         if(Path.size() <= 0) continue;
 	
 #if OSC_DEBUG
-    	Owner().m_put("DEBUG",MESS_INFO,"%s:Scan dir <%s> !",s_name,Path.c_str());
+    	owner().mPut("DEBUG",MESS_INFO,"%s:Scan dir <%s> !",s_name,Path.c_str());
 #endif  
 
 	// Convert to absolutly path
@@ -327,7 +311,7 @@ void TModSchedul::ScanDir( const string &Paths, vector<string> &files, bool new_
         closedir(IdDir);
 	
 #if OSC_DEBUG
-    	Owner().m_put("DEBUG",MESS_DEBUG,"%s:Scan dir <%s> ok !",s_name,Path.c_str());
+    	owner().mPut("DEBUG",MESS_DEBUG,"%s:Scan dir <%s> ok !",s_name,Path.c_str());
 #endif    
 	
     } while(id != (int)string::npos);
@@ -347,7 +331,7 @@ bool TModSchedul::CheckFile( const string &name, bool new_f ) const
     void *h_lib = dlopen(name.c_str(),RTLD_GLOBAL|RTLD_LAZY);
     if(h_lib == NULL)
     {
-        Owner().m_put("SYS",MESS_WARNING,"%s:SO %s error: %s !",s_name,name.c_str(),dlerror());
+        owner().mPut("SYS",MESS_WARNING,"%s:SO %s error: %s !",s_name,name.c_str(),dlerror());
         return(false);
     }
     else dlclose(h_lib);        
@@ -360,7 +344,7 @@ bool TModSchedul::CheckFile( const string &name, bool new_f ) const
     return(true);
 }
 
-int  TModSchedul::RegSO( const string &name )
+int  TModSchedul::libReg( const string &name )
 {
     struct stat file_stat;
 
@@ -381,13 +365,13 @@ int  TModSchedul::RegSO( const string &name )
     return(i_sh);    
 }
 
-void TModSchedul::UnregSO( const string &name )
+void TModSchedul::libUnreg( const string &name )
 {
     ResAlloc res(hd_res,true);
     for(unsigned i_sh = 0; i_sh < SchHD.size(); i_sh++)
        	if( SchHD[i_sh]->name == name ) 
 	{
-	    if( SchHD[i_sh]->hd ) DetSO( name );
+	    if( SchHD[i_sh]->hd ) libDet( name );
 	    delete SchHD[i_sh];
 	    SchHD.erase(SchHD.begin()+i_sh);
 	    return;
@@ -395,7 +379,7 @@ void TModSchedul::UnregSO( const string &name )
     throw TError("%s: SO <%s> no avoid!",o_name,name.c_str());
 }
     
-void TModSchedul::AttSO( const string &name, bool full, int dest )
+void TModSchedul::libAtt( const string &name, bool full, int dest )
 {
     ResAlloc res(hd_res,true);
     for(unsigned i_sh = 0; i_sh < SchHD.size(); i_sh++)
@@ -409,7 +393,7 @@ void TModSchedul::AttSO( const string &name, bool full, int dest )
 		throw TError("%s: SO <%s> error: %s !",o_name,name.c_str(),dlerror());	    
 	    
 	    //Connect to module function
-	    SAtMod (*module)( int );
+	    TModule::SAt (*module)( int );
 	    (void *)module = dlsym(h_lib,"module");
 	    if( dlerror() != NULL )
 	    {
@@ -418,7 +402,7 @@ void TModSchedul::AttSO( const string &name, bool full, int dest )
 	    }    
 	    
 	    //Connect to attach function	    
-	    TModule *(*attach)( const SAtMod &, const string & );
+	    TModule *(*attach)( const TModule::SAt &, const string & );
 	    (void *)attach = dlsym(h_lib,"attach");
 	    if( dlerror() != NULL )
 	    {
@@ -430,48 +414,45 @@ void TModSchedul::AttSO( const string &name, bool full, int dest )
 	    stat(name.c_str(),&file_stat);
     
 	    int n_mod=0, add_mod=0;
-	    SAtMod AtMod;
-	    while( (AtMod = (module)( n_mod++ )).name.size() )
+	    TModule::SAt AtMod;
+	    while( (AtMod = (module)( n_mod++ )).id.size() )
 	    {
 		for( unsigned i_grm = 0; i_grm < grpmod.size(); i_grm++)
 		{
 		    if(dest >= 0) i_grm = dest;
-		    if( AtMod.type == grpmod[i_grm]->gmd_Name() )
+		    if( AtMod.type == grpmod[i_grm]->gmdName() )
 		    { 
-			unsigned hd;
 			//Check type module version
-			if( AtMod.t_ver != grpmod[i_grm]->gmd_Ver() )
+			if( AtMod.t_ver != grpmod[i_grm]->gmdVer() )
 			{
-			    Owner().m_put("SYS",MESS_WARNING,"%s:%s for type <%s> no support module version: %d!",
-				s_name,AtMod.name.c_str(),AtMod.type.c_str(),AtMod.t_ver);
+			    owner().mPut("SYS",MESS_WARNING,"%s:%s for type <%s> no support module version: %d!",
+				s_name,AtMod.id.c_str(),AtMod.type.c_str(),AtMod.t_ver);
 			    break;
 			}
 			//Check avoid module
-			try{ hd = grpmod[i_grm]->gmd_att( AtMod.name ); }
+			try{ grpmod[i_grm]->gmdAt( AtMod.id ); }
 			catch(TError)
 			{
 			    //Attach new module
 			    TModule *LdMod = (attach)( AtMod, name );
 			    if( LdMod == NULL )
 			    {
-				Owner().m_put("SYS",MESS_WARNING,"%s:Attach module <%s> error!",s_name,AtMod.name.c_str());
+				owner().mPut("SYS",MESS_WARNING,"%s:Attach module <%s> error!",s_name,AtMod.id.c_str());
 				break;
 			    }
 			    //Add atached module
-			    grpmod[i_grm]->gmd_add(LdMod);
-			    hd = grpmod[i_grm]->gmd_att(LdMod->mod_Name());
-			    SUse t_suse = { i_grm, hd };
+			    grpmod[i_grm]->gmdAdd(LdMod);
+			    SUse t_suse = { i_grm, grpmod[i_grm]->gmdAt(LdMod->modName()) };
 			    SchHD[i_sh]->use.push_back( t_suse );
 			    if(full)
 			    {
-				grpmod[i_grm]->gmd_Init();
-				grpmod[i_grm]->gmd_Start();
+				grpmod[i_grm]->gmdInit();
+				grpmod[i_grm]->gmdStart();
 			    }
 			    add_mod++;
 			    break;
 			}
-			grpmod[i_grm]->gmd_det( hd );
-			Owner().m_put("SYS",MESS_WARNING,"%s:Module %s already avoid!",s_name,AtMod.name.c_str());		    
+			owner().mPut("SYS",MESS_WARNING,"%s:Module %s already avoid!",s_name,AtMod.id.c_str());		    
 		    }
 		    if(dest >= 0) break;
 		}
@@ -483,20 +464,21 @@ void TModSchedul::AttSO( const string &name, bool full, int dest )
     throw TError("%s: SO <%s> no avoid!",o_name,name.c_str());
 }
 
-void TModSchedul::DetSO( const string &name )
+void TModSchedul::libDet( const string &name )
 {
     ResAlloc res(hd_res,true);
     for(unsigned i_sh = 0; i_sh < SchHD.size(); i_sh++)
     {
        	if( SchHD[i_sh]->name == name && SchHD[i_sh]->hd )
 	{
+	    
     	    while( SchHD[i_sh]->use.size() )
 	    {
-		string n_mod = grpmod[SchHD[i_sh]->use[0].id_tmod]->gmd_at( SchHD[i_sh]->use[0].id_mod ).mod_Name();
-	       	grpmod[SchHD[i_sh]->use[0].id_tmod]->gmd_det( SchHD[i_sh]->use[0].id_mod );
-	       	grpmod[SchHD[i_sh]->use[0].id_tmod]->gmd_del( n_mod );
+		string n_mod = SchHD[i_sh]->use[0].mod.at().modName();
+		SchHD[i_sh]->use[0].mod.free();
+	       	grpmod[SchHD[i_sh]->use[0].id_tmod]->gmdDel( n_mod );
 		SchHD[i_sh]->use.erase(SchHD[i_sh]->use.begin());
-	    }
+	    }	    
 	    dlclose(SchHD[i_sh]->hd);
 	    SchHD[i_sh]->hd = NULL;
 	    return;
@@ -514,7 +496,7 @@ bool TModSchedul::CheckAuto( const string &name) const
     return(false);
 }
 
-void TModSchedul::ListSO( vector<string> &list )
+void TModSchedul::libList( vector<string> &list )
 {  
     ResAlloc res(hd_res,false);
     list.clear();
@@ -522,7 +504,7 @@ void TModSchedul::ListSO( vector<string> &list )
        	list.push_back( SchHD[i_sh]->name );
 }
 
-SHD TModSchedul::SO( const string &name )
+TModSchedul::SHD TModSchedul::lib( const string &name )
 {
     ResAlloc res(hd_res,false);
     string nm_t = SYS->FixFName(name);
@@ -532,7 +514,7 @@ SHD TModSchedul::SO( const string &name )
     throw TError("%s: SO <%s> no avoid!",o_name,nm_t.c_str());
 }
 
-void TModSchedul::Load( const string &name, int dest, bool full)
+void TModSchedul::libLoad( const string &name, int dest, bool full)
 {
     vector<string> files;
 
@@ -545,13 +527,13 @@ void TModSchedul::Load( const string &name, int dest, bool full)
 	    if( SchHD[i_sh]->name == files[i_f] ) break;
 	if(i_sh < SchHD.size())
 	{
-	    if(st_auto) DetSO(files[i_f]);
+	    if(st_auto) libDet(files[i_f]);
 	}
-	RegSO(files[i_f]);	
+	libReg(files[i_f]);	
 	if(st_auto) 
 	{
-	    try{ AttSO(files[i_f],full,dest); }
-	    catch( TError err ){ Owner().m_put("SYS",MESS_WARNING,"%s:%s",s_name,err.what().c_str()); }
+	    try{ libAtt(files[i_f],full,dest); }
+	    catch( TError err ){ owner().mPut("SYS",MESS_WARNING,"%s:%s",s_name,err.what().c_str()); }
 	}
     }
 }
@@ -559,58 +541,64 @@ void TModSchedul::Load( const string &name, int dest, bool full)
 //==============================================================
 //================== Controll functions ========================
 //==============================================================
-void TModSchedul::ctr_fill_info( XMLNode *inf )
+void TModSchedul::ctrStat_( XMLNode *inf )
 {
+    char *i_cntr = 
+	"<oscada_cntr>"
+	" <area id='a_ms' dscr='Subsystem control.' acs='0440'>"
+	"  <fld id='mod_path' com='1' cfg='1' dest='dir' tp='str'/>"
+	"  <list id='mod_auto' tp='str' dest='file' s_com='add,ins,edit,del'/>"
+	" </area>"
+	" <area id='help'>"
+	"  <fld id='g_help' acs='0440' tp='str' cols='90' rows='5'/>"
+	" </area>"	
+	"</oscada_cntr>";
     char *dscr = "dscr";
+    
     XMLNode *c_nd;
-    inf->load_xml( i_cntr );
-    inf->set_text(Mess->I18N("Module sheduler subsystem"));
+    inf->load( i_cntr );
+    inf->text(Mess->I18N("Module sheduler subsystem"));
     //a_ms
-    c_nd = inf->get_child(0);
-    c_nd->set_attr(dscr,Mess->I18N("Subsystem control"));
-    c_nd->get_child(0)->set_attr(dscr,Mess->I18N("Path to shared libs(modules)"));
-    c_nd->get_child(1)->set_attr(dscr,Mess->I18N("List of auto conected shared libs(modules)"));
-    c_nd->get_child(2)->set_attr(dscr,Mess->I18N("Options help"));
+    c_nd = inf->childGet(0);
+    c_nd->attr(dscr,Mess->I18N("Subsystem"));
+    c_nd->childGet(0)->attr(dscr,Mess->I18N("Path to shared libs(modules)"));
+    c_nd->childGet(1)->attr(dscr,Mess->I18N("List of auto conected shared libs(modules)"));
+    c_nd = inf->childGet(1);
+    c_nd->attr(dscr,Mess->I18N("Help"));
+    c_nd->childGet(0)->attr(dscr,Mess->I18N("Options help"));    
 }
 
-void TModSchedul::ctr_din_get_( const string &a_path, XMLNode *opt )
+void TModSchedul::ctrDinGet_( const string &a_path, XMLNode *opt )
 {
-    vector<string> list;
-    
-    string t_id = ctr_path_l(a_path,0);
-    if( t_id == "a_ms" )
+    if( a_path == "/a_ms/mod_path" )	ctrSetS( opt, m_mod_path );
+    else if( a_path == "/a_ms/mod_auto" )
     {
-    	t_id = ctr_path_l(a_path,1);
-	if( t_id == "mod_path" )    ctr_opt_setS( opt, m_mod_path );
-	else if( t_id == "mod_auto" )
-	    for( unsigned i_a=0; i_a < m_am_list.size(); i_a++ )
-		ctr_opt_setS( opt, m_am_list[i_a], i_a );
-	else if( t_id == "g_help" ) ctr_opt_setS( opt, opt_descr() );       
+	opt->childClean();
+	for( unsigned i_a=0; i_a < m_am_list.size(); i_a++ )
+	    ctrSetS( opt, m_am_list[i_a], i_a );
     }
+    else if( a_path == "/help/g_help" )	ctrSetS( opt, optDescr() );       
+    else throw TError("(%s) Branch %s error!",o_name,a_path.c_str());
 } 
 
-void TModSchedul::ctr_din_set_( const string &a_path, XMLNode *opt )
+void TModSchedul::ctrDinSet_( const string &a_path, XMLNode *opt )
 {
-    string t_id = ctr_path_l(a_path,0);
-    if( t_id == "a_ms" )
-    {
-    	t_id = ctr_path_l(a_path,1);
-	if( t_id == "mod_path" ) m_mod_path = ctr_opt_getS( opt );
-	else if( t_id == "mod_auto" )
-	    for( int i_el=0; i_el < opt->get_child_count(); i_el++)
-    	    {
-    		XMLNode *t_c = opt->get_child(i_el);
-    		if( t_c->get_name() == "el")
-    		{
-    		    if(t_c->get_attr("do") == "add")      
-			m_am_list.push_back(t_c->get_text());
-		    else if(t_c->get_attr("do") == "ins") 
-			m_am_list.insert(m_am_list.begin()+atoi(t_c->get_attr("id").c_str()),t_c->get_text()); 
-		    else if(t_c->get_attr("do") == "edit") 
-			m_am_list[atoi(t_c->get_attr("id").c_str())] = t_c->get_text();  
-    		    else if(t_c->get_attr("do") == "del") 
-			m_am_list.erase(m_am_list.begin()+atoi(t_c->get_attr("id").c_str()));
-    		}
-    	    }
-    }
+    if( a_path == "/a_ms/mod_path" ) m_mod_path = ctrGetS( opt );
+    else if( a_path.substr(0,14) == "/a_ms/mod_auto" )
+	for( int i_el=0; i_el < opt->childSize(); i_el++)
+	{
+	    XMLNode *t_c = opt->childGet(i_el);
+	    if( t_c->name() == "el")
+	    {
+		if(t_c->attr("do") == "add")      
+		    m_am_list.push_back(t_c->text());
+		else if(t_c->attr("do") == "ins") 
+		    m_am_list.insert(m_am_list.begin()+atoi(t_c->attr("id").c_str()),t_c->text()); 
+		else if(t_c->attr("do") == "edit") 
+		    m_am_list[atoi(t_c->attr("id").c_str())] = t_c->text();  
+		else if(t_c->attr("do") == "del") 
+		    m_am_list.erase(m_am_list.begin()+atoi(t_c->attr("id").c_str()));
+	    }
+	}
+    else throw TError("(%s) Branch %s error!",o_name,a_path.c_str());
 }
