@@ -43,46 +43,39 @@ class TParamContr : public TContr, public TConfig, public TValue
 	TParamContr( const string &name, TTipParam *tpprm, TController *contr); 
 	virtual ~TParamContr();
 	
-    	string &Name()       { return(m_name); }
-    	string &LName()      { return(m_lname); }
+    	string &name()       { return(m_name); }
+    	string &lName()      { return(m_lname); }
 	
-    	bool   &auto_export(){ return(m_aexport); }
-    	bool   st_export()   { return(m_export); }
+    	bool &toExport(){ return(m_aexport); }
+    	bool exportStat()   { return(m_export); }
 	
-	void Load( );
-	void Save( );
+	void load( );
+	void save( );
 	
-    	void Export( ); 
-	void UnExport( );
+    	void exportPrm( ); 
+	void unExportPrm( );
 	
 	// Compare object
     	bool operator==( TParamContr & PrmCntr )
-	{ if( Name() == PrmCntr.Name() ) return(true); return(false); };
+	{ if( name() == PrmCntr.name() ) return(true); return(false); };
 	// Equaly config 
     	TParamContr & operator=( TParamContr & PrmCntr );
 
-	//TValue &val();
-	// Check for new value type
-    	//void UpdateVAL();            //????
 	// Enable parameter and open access to value
-    	virtual void Enable();
+    	virtual void enable();
 	// Disable parameter and close access to value
-    	virtual void Disable();
+    	virtual void disable();
 	// Type of parameter
-    	TTipParam   &Type() { return(*tipparm); }
-	TController &Owner() { return(*owner); }
-    /**Attributes: */
-    public:
-
+    	TTipParam   &type() { return(*tipparm); }
+	
+	TController &owner() { return(*m_owner); }
+	
     protected:    
 	//================== Controll functions ========================
-	void ctr_fill_info( XMLNode *inf );
-	void ctr_din_get_( const string &a_path, XMLNode *opt );
-	void ctr_din_set_( const string &a_path, XMLNode *opt );
-	void ctr_cmd_go_( const string &a_path, XMLNode *fld, XMLNode *rez );
+	void ctrStat_( XMLNode *inf );
+	void ctrDinGet_( const string &a_path, XMLNode *opt );
+	void ctrDinSet_( const string &a_path, XMLNode *opt );
 	
-    private:
-	//virtual TConfig *vl_GetCfg( ) { return(this); }
     /**Attributes: */
     private:
         string &m_name;
@@ -92,11 +85,10 @@ class TParamContr : public TContr, public TConfig, public TValue
 	
 	short       own;   // id from password
 	short       grp;   // id from group
-	TController *owner;
+	TController *m_owner;
 	TTipParam   *tipparm;
     
 	static const char *o_name;
-        static const char *i_cntr;
 };
 
 #endif // TPARAMCONTR_H
