@@ -29,33 +29,30 @@
 //=========== TSpecialS ==========================================
 //================================================================
 const char *TSpecialS::o_name = "TSpecialS";
-const char *TSpecialS::i_cntr = 
-    "<area id='a_gn' acs='0440'>"
-    " <fld id='g_help' acs='0440' tp='str' cols='90' rows='5'/>"
-    "</area>";
 
 TSpecialS::TSpecialS( TKernel *app ) : TGRPModule(app,"Special")  
 {
     s_name = "Specials";
 }
 
-string TSpecialS::opt_descr( )
+string TSpecialS::optDescr( )
 {
     return(Mess->I18N(
     	"======================= The special subsystem options =====================\n"
-	"    --SPModPath=<path>  Set moduls <path>;\n"));
+	"    --SPModPath=<path>  Set moduls <path>;\n\n"));
 }
 
-void TSpecialS::gmd_CheckCommandLine( )
+void TSpecialS::gmdCheckCommandLine( )
 {
-    TGRPModule::gmd_CheckCommandLine( );
+    TGRPModule::gmdCheckCommandLine( );
     
     int next_opt;
     char *short_opt="h";
     struct option long_opt[] =
     {
-	{"SPModPath" ,1,NULL,'m'},
-	{NULL        ,0,NULL,0  }
+	{"help"     ,0,NULL,'h'},
+	{"SPModPath",1,NULL,'m'},
+	{NULL       ,0,NULL,0  }
     };
 
     optind=opterr=0;	
@@ -64,66 +61,58 @@ void TSpecialS::gmd_CheckCommandLine( )
 	next_opt=getopt_long(SYS->argc,(char * const *)SYS->argv,short_opt,long_opt,NULL);
 	switch(next_opt)
 	{
-	    case 'h': fprintf(stdout,opt_descr().c_str()); break;
+	    case 'h': fprintf(stdout,optDescr().c_str()); break;
 	    case 'm': DirPath = optarg;     break;
 	    case -1 : break;
 	}
     } while(next_opt != -1);
-//    if(optind < App->argc) pr_opt_descr(stdout);
 }
 
-void TSpecialS::gmd_UpdateOpt()
+void TSpecialS::gmdUpdateOpt()
 {
-    TGRPModule::gmd_UpdateOpt();
+    TGRPModule::gmdUpdateOpt();
 }
 
-void TSpecialS::gmd_Start( )
+void TSpecialS::gmdStart( )
 {
     vector<string> list;
-    gmd_list(list);
+    gmdList(list);
     for(unsigned i_sp = 0; i_sp < list.size(); i_sp++)
-	((TSpecial &)gmd_at(list[i_sp]).at()).start();
+	((TSpecial &)gmdAt(list[i_sp]).at()).start();
 }              
 
-void TSpecialS::gmd_Stop( )
+void TSpecialS::gmdStop( )
 {
     vector<string> list;
-    gmd_list(list);
+    gmdList(list);
     for(unsigned i_sp = 0; i_sp < list.size(); i_sp++)
-	((TSpecial &)gmd_at(list[i_sp]).at()).stop();
+	((TSpecial &)gmdAt(list[i_sp]).at()).stop();
 }
 
 //=========== Control ==========================================
-void TSpecialS::ctr_fill_info( XMLNode *inf )
+void TSpecialS::ctrStat_( XMLNode *inf )
 {
     char *dscr = "dscr";
-    TGRPModule::ctr_fill_info( inf );
     
-    XMLNode *n_add = inf->add_child();
-    n_add->load_xml(i_cntr);
-    n_add->set_attr(dscr,Mess->I18N("Subsystem control"));
-    n_add->get_child(0)->set_attr(dscr,Mess->I18N("Options help"));
+    TGRPModule::ctrStat_( inf );
+	
+    char *i_help =
+        "<fld id='g_help' acs='0440' tp='str' cols='90' rows='5'/>";
+		    
+    XMLNode *n_add = inf->childGet("id","help")->childAdd();
+    n_add->load(i_help);
+    n_add->attr(dscr,Mess->I18N("Options help"));
 }
 
-void TSpecialS::ctr_din_get_( const string &a_path, XMLNode *opt )
+void TSpecialS::ctrDinGet_( const string &a_path, XMLNode *opt )
 {
-    TGRPModule::ctr_din_get_( a_path, opt );
-    
-    string t_id = ctr_path_l(a_path,0);
-    if( t_id == "a_gn" )
-    {
-	t_id = ctr_path_l(a_path,1);
-	if( t_id == "g_help" ) ctr_opt_setS( opt, opt_descr() );       
-    }   
+    if( a_path == "/help/g_help" ) ctrSetS( opt, optDescr() );       
+    else TGRPModule::ctrDinGet_( a_path, opt );
 }
 //================================================================
 //=========== TSpecial ===========================================
 //================================================================
 const char *TSpecial::o_name = "TSpecial";
-const char *TSpecial::i_cntr = 
-    "<area id='a_prm'>"
-    " <fld id='r_st' acs='0664' tp='bool'/>"
-    "</area>";
 
 TSpecial::TSpecial() : run_st(false)
 {
@@ -131,39 +120,31 @@ TSpecial::TSpecial() : run_st(false)
 }
 
 //================== Controll functions ========================
-void TSpecial::ctr_fill_info( XMLNode *inf )
+void TSpecial::ctrStat_( XMLNode *inf )
 {
+    char *i_cntr = 
+	"<area id='prm'>"
+	" <fld id='st' acs='0664' tp='bool'/>"
+	"</area>";
     char *dscr = "dscr";
-    TModule::ctr_fill_info( inf );
     
-    XMLNode *n_add = inf->add_child();
-    n_add->load_xml(i_cntr);
-    n_add->set_attr(dscr,Mess->I18N("Special control"));
-    n_add->get_child(0)->set_attr(dscr,Mess->I18N("Runing"));
+    TModule::ctrStat_( inf );
+    
+    XMLNode *n_add = inf->childIns(0);
+    n_add->load(i_cntr);
+    n_add->attr(dscr,Mess->I18N("Special"));
+    n_add->childGet(0)->attr(dscr,Mess->I18N("Run"));
 }
 
-void TSpecial::ctr_din_get_( const string &a_path, XMLNode *opt )
+void TSpecial::ctrDinGet_( const string &a_path, XMLNode *opt )
 {
-    TModule::ctr_din_get_( a_path, opt );
-    
-    string t_id = ctr_path_l(a_path,0);    
-    if( t_id == "a_prm" )
-    {
-    	t_id = ctr_path_l(a_path,1);
-    	if( t_id == "r_st" )  ctr_opt_setB( opt, run_st );
-    }    
+    if( a_path == "/prm/st" )	ctrSetB( opt, run_st );
+    else TModule::ctrDinGet_( a_path, opt );
 }
 
-void TSpecial::ctr_din_set_( const string &a_path, XMLNode *opt )
+void TSpecial::ctrDinSet_( const string &a_path, XMLNode *opt )
 {
-    TModule::ctr_din_set_( a_path, opt );
-    
-    string t_id = ctr_path_l(a_path,0);    
-    if( t_id == "a_prm" )
-    {
-    	t_id = ctr_path_l(a_path,1);
-    	if( t_id == "r_st" ) 
-	    if( ctr_opt_getB( opt ) ) start(); else stop();
-    }    
+    if( a_path == "/prm/st" )	if( ctrGetB( opt ) ) start(); else stop();
+    else TModule::ctrDinSet_( a_path, opt );
 }
 
